!function(r){var n={};function o(e){if(n[e])return n[e].exports;var t=n[e]={i:e,l:!1,exports:{}};return r[e].call(t.exports,t,t.exports,o),t.l=!0,t.exports}o.m=r,o.c=n,o.d=function(e,t,r){o.o(e,t)||Object.defineProperty(e,t,{enumerable:!0,get:r})},o.r=function(e){"undefined"!=typeof Symbol&&Symbol.toStringTag&&Object.defineProperty(e,Symbol.toStringTag,{value:"Module"}),Object.defineProperty(e,"__esModule",{value:!0})},o.t=function(t,e){if(1&e&&(t=o(t)),8&e)return t;if(4&e&&"object"==typeof t&&t&&t.__esModule)return t;var r=Object.create(null);if(o.r(r),Object.defineProperty(r,"default",{enumerable:!0,value:t}),2&e&&"string"!=typeof t)for(var n in t)o.d(r,n,function(e){return t[e]}.bind(null,n));return r},o.n=function(e){var t=e&&e.__esModule?function(){return e.default}:function(){return e};return o.d(t,"a",t),t},o.o=function(e,t){return Object.prototype.hasOwnProperty.call(e,t)},o.p="",o(o.s="./test/xdsm-test.js")}({"./node_modules/base64-js/index.js":
/*!*****************************************!*\
  !*** ./node_modules/base64-js/index.js ***!
  \*****************************************/
/*! no static exports found */function(e,t,r){"use strict";t.byteLength=function(e){var t=f(e),r=t[0],n=t[1];return 3*(r+n)/4-n},t.toByteArray=function(e){var t,r,n=f(e),o=n[0],i=n[1],s=new l(function(e,t,r){return 3*(t+r)/4-r}(0,o,i)),a=0,u=0<i?o-4:o;for(r=0;r<u;r+=4)t=d[e.charCodeAt(r)]<<18|d[e.charCodeAt(r+1)]<<12|d[e.charCodeAt(r+2)]<<6|d[e.charCodeAt(r+3)],s[a++]=t>>16&255,s[a++]=t>>8&255,s[a++]=255&t;2===i&&(t=d[e.charCodeAt(r)]<<2|d[e.charCodeAt(r+1)]>>4,s[a++]=255&t);1===i&&(t=d[e.charCodeAt(r)]<<10|d[e.charCodeAt(r+1)]<<4|d[e.charCodeAt(r+2)]>>2,s[a++]=t>>8&255,s[a++]=255&t);return s},t.fromByteArray=function(e){for(var t,r=e.length,n=r%3,o=[],i=0,s=r-n;i<s;i+=16383)o.push(u(e,i,s<i+16383?s:i+16383));1==n?(t=e[r-1],o.push(a[t>>2]+a[t<<4&63]+"==")):2==n&&(t=(e[r-2]<<8)+e[r-1],o.push(a[t>>10]+a[t>>4&63]+a[t<<2&63]+"="));return o.join("")};for(var a=[],d=[],l="undefined"!=typeof Uint8Array?Uint8Array:Array,n="ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/",o=0,i=n.length;o<i;++o)a[o]=n[o],d[n.charCodeAt(o)]=o;function f(e){var t=e.length;if(0<t%4)throw new Error("Invalid string. Length must be a multiple of 4");var r=e.indexOf("=");return-1===r&&(r=t),[r,r===t?0:4-r%4]}function u(e,t,r){for(var n,o,i=[],s=t;s<r;s+=3)n=(e[s]<<16&16711680)+(e[s+1]<<8&65280)+(255&e[s+2]),i.push(a[(o=n)>>18&63]+a[o>>12&63]+a[o>>6&63]+a[63&o]);return i.join("")}d["-".charCodeAt(0)]=62,d["_".charCodeAt(0)]=63},"./node_modules/buffer/index.js":
/*!**************************************!*\
  !*** ./node_modules/buffer/index.js ***!
  \**************************************/
/*! no static exports found */function(e,I,U){"use strict";(function(e){
/*!
 * The buffer module from node.js, for the browser.
 *
 * @author   Feross Aboukhadijeh <feross@feross.org> <http://feross.org>
 * @license  MIT
 */
var n=U(/*! base64-js */"./node_modules/base64-js/index.js"),i=U(/*! ieee754 */"./node_modules/ieee754/index.js"),s=U(/*! isarray */"./node_modules/isarray/index.js");function r(){return f.TYPED_ARRAY_SUPPORT?2147483647:1073741823}function a(e,t){if(r()<t)throw new RangeError("Invalid typed array length");return f.TYPED_ARRAY_SUPPORT?(e=new Uint8Array(t)).__proto__=f.prototype:(null===e&&(e=new f(t)),e.length=t),e}function f(e,t,r){if(!(f.TYPED_ARRAY_SUPPORT||this instanceof f))return new f(e,t,r);if("number"!=typeof e)return o(this,e,t,r);if("string"==typeof t)throw new Error("If encoding is specified then the first argument must be a string");return d(this,e)}function o(e,t,r,n){if("number"==typeof t)throw new TypeError('"value" argument must not be a number');return"undefined"!=typeof ArrayBuffer&&t instanceof ArrayBuffer?function(e,t,r,n){if(t.byteLength,r<0||t.byteLength<r)throw new RangeError("'offset' is out of bounds");if(t.byteLength<r+(n||0))throw new RangeError("'length' is out of bounds");t=void 0===r&&void 0===n?new Uint8Array(t):void 0===n?new Uint8Array(t,r):new Uint8Array(t,r,n);f.TYPED_ARRAY_SUPPORT?(e=t).__proto__=f.prototype:e=l(e,t);return e}(e,t,r,n):"string"==typeof t?function(e,t,r){"string"==typeof r&&""!==r||(r="utf8");if(!f.isEncoding(r))throw new TypeError('"encoding" must be a valid string encoding');var n=0|p(t,r),o=(e=a(e,n)).write(t,r);o!==n&&(e=e.slice(0,o));return e}(e,t,r):function(e,t){if(f.isBuffer(t)){var r=0|c(t.length);return 0===(e=a(e,r)).length||t.copy(e,0,0,r),e}if(t){if("undefined"!=typeof ArrayBuffer&&t.buffer instanceof ArrayBuffer||"length"in t)return"number"!=typeof t.length||function(e){return e!=e}(t.length)?a(e,0):l(e,t);if("Buffer"===t.type&&s(t.data))return l(e,t.data)}throw new TypeError("First argument must be a string, Buffer, ArrayBuffer, Array, or array-like object.")}(e,t)}function u(e){if("number"!=typeof e)throw new TypeError('"size" argument must be a number');if(e<0)throw new RangeError('"size" argument must not be negative')}function d(e,t){if(u(t),e=a(e,t<0?0:0|c(t)),!f.TYPED_ARRAY_SUPPORT)for(var r=0;r<t;++r)e[r]=0;return e}function l(e,t){var r=t.length<0?0:0|c(t.length);e=a(e,r);for(var n=0;n<r;n+=1)e[n]=255&t[n];return e}function c(e){if(e>=r())throw new RangeError("Attempt to allocate Buffer larger than maximum size: 0x"+r().toString(16)+" bytes");return 0|e}function p(e,t){if(f.isBuffer(e))return e.length;if("undefined"!=typeof ArrayBuffer&&"function"==typeof ArrayBuffer.isView&&(ArrayBuffer.isView(e)||e instanceof ArrayBuffer))return e.byteLength;"string"!=typeof e&&(e=""+e);var r=e.length;if(0===r)return 0;for(var n=!1;;)switch(t){case"ascii":case"latin1":case"binary":return r;case"utf8":case"utf-8":case void 0:return B(e).length;case"ucs2":case"ucs-2":case"utf16le":case"utf-16le":return 2*r;case"hex":return r>>>1;case"base64":return q(e).length;default:if(n)return B(e).length;t=(""+t).toLowerCase(),n=!0}}function h(e,t,r){var n=e[t];e[t]=e[r],e[r]=n}function m(e,t,r,n,o){if(0===e.length)return-1;if("string"==typeof r?(n=r,r=0):2147483647<r?r=2147483647:r<-2147483648&&(r=-2147483648),r=+r,isNaN(r)&&(r=o?0:e.length-1),r<0&&(r=e.length+r),r>=e.length){if(o)return-1;r=e.length-1}else if(r<0){if(!o)return-1;r=0}if("string"==typeof t&&(t=f.from(t,n)),f.isBuffer(t))return 0===t.length?-1:y(e,t,r,n,o);if("number"==typeof t)return t&=255,f.TYPED_ARRAY_SUPPORT&&"function"==typeof Uint8Array.prototype.indexOf?o?Uint8Array.prototype.indexOf.call(e,t,r):Uint8Array.prototype.lastIndexOf.call(e,t,r):y(e,[t],r,n,o);throw new TypeError("val must be string, number or Buffer")}function y(e,t,r,n,o){var i,s=1,a=e.length,u=t.length;if(void 0!==n&&("ucs2"===(n=String(n).toLowerCase())||"ucs-2"===n||"utf16le"===n||"utf-16le"===n)){if(e.length<2||t.length<2)return-1;a/=s=2,u/=2,r/=2}function d(e,t){return 1===s?e[t]:e.readUInt16BE(t*s)}if(o){var l=-1;for(i=r;i<a;i++)if(d(e,i)===d(t,-1===l?0:i-l)){if(-1===l&&(l=i),i-l+1===u)return l*s}else-1!==l&&(i-=i-l),l=-1}else for(a<r+u&&(r=a-u),i=r;0<=i;i--){for(var f=!0,c=0;c<u;c++)if(d(e,i+c)!==d(t,c)){f=!1;break}if(f)return i}return-1}function b(e,t,r,n){r=Number(r)||0;var o=e.length-r;n?o<(n=Number(n))&&(n=o):n=o;var i=t.length;if(i%2!=0)throw new TypeError("Invalid hex string");i/2<n&&(n=i/2);for(var s=0;s<n;++s){var a=parseInt(t.substr(2*s,2),16);if(isNaN(a))return s;e[r+s]=a}return s}function g(e,t,r,n){return C(function(e){for(var t=[],r=0;r<e.length;++r)t.push(255&e.charCodeAt(r));return t}(t),e,r,n)}function v(e,t,r){return 0===t&&r===e.length?n.fromByteArray(e):n.fromByteArray(e.slice(t,r))}function _(e,t,r){r=Math.min(e.length,r);for(var n=[],o=t;o<r;){var i,s,a,u,d=e[o],l=null,f=239<d?4:223<d?3:191<d?2:1;if(o+f<=r)switch(f){case 1:d<128&&(l=d);break;case 2:128==(192&(i=e[o+1]))&&127<(u=(31&d)<<6|63&i)&&(l=u);break;case 3:i=e[o+1],s=e[o+2],128==(192&i)&&128==(192&s)&&2047<(u=(15&d)<<12|(63&i)<<6|63&s)&&(u<55296||57343<u)&&(l=u);break;case 4:i=e[o+1],s=e[o+2],a=e[o+3],128==(192&i)&&128==(192&s)&&128==(192&a)&&65535<(u=(15&d)<<18|(63&i)<<12|(63&s)<<6|63&a)&&u<1114112&&(l=u)}null===l?(l=65533,f=1):65535<l&&(l-=65536,n.push(l>>>10&1023|55296),l=56320|1023&l),n.push(l),o+=f}return function(e){var t=e.length;if(t<=w)return String.fromCharCode.apply(String,e);var r="",n=0;for(;n<t;)r+=String.fromCharCode.apply(String,e.slice(n,n+=w));return r}(n)}I.Buffer=f,I.SlowBuffer=function(e){+e!=e&&(e=0);return f.alloc(+e)},I.INSPECT_MAX_BYTES=50,f.TYPED_ARRAY_SUPPORT=void 0!==e.TYPED_ARRAY_SUPPORT?e.TYPED_ARRAY_SUPPORT:function(){try{var e=new Uint8Array(1);return e.__proto__={__proto__:Uint8Array.prototype,foo:function(){return 42}},42===e.foo()&&"function"==typeof e.subarray&&0===e.subarray(1,1).byteLength}catch(e){return!1}}(),I.kMaxLength=r(),f.poolSize=8192,f._augment=function(e){return e.__proto__=f.prototype,e},f.from=function(e,t,r){return o(null,e,t,r)},f.TYPED_ARRAY_SUPPORT&&(f.prototype.__proto__=Uint8Array.prototype,f.__proto__=Uint8Array,"undefined"!=typeof Symbol&&Symbol.species&&f[Symbol.species]===f&&Object.defineProperty(f,Symbol.species,{value:null,configurable:!0})),f.alloc=function(e,t,r){return function(e,t,r,n){return u(t),t<=0?a(e,t):void 0!==r?"string"==typeof n?a(e,t).fill(r,n):a(e,t).fill(r):a(e,t)}(null,e,t,r)},f.allocUnsafe=function(e){return d(null,e)},f.allocUnsafeSlow=function(e){return d(null,e)},f.isBuffer=function(e){return!(null==e||!e._isBuffer)},f.compare=function(e,t){if(!f.isBuffer(e)||!f.isBuffer(t))throw new TypeError("Arguments must be Buffers");if(e===t)return 0;for(var r=e.length,n=t.length,o=0,i=Math.min(r,n);o<i;++o)if(e[o]!==t[o]){r=e[o],n=t[o];break}return r<n?-1:n<r?1:0},f.isEncoding=function(e){switch(String(e).toLowerCase()){case"hex":case"utf8":case"utf-8":case"ascii":case"latin1":case"binary":case"base64":case"ucs2":case"ucs-2":case"utf16le":case"utf-16le":return!0;default:return!1}},f.concat=function(e,t){if(!s(e))throw new TypeError('"list" argument must be an Array of Buffers');if(0===e.length)return f.alloc(0);var r;if(void 0===t)for(r=t=0;r<e.length;++r)t+=e[r].length;var n=f.allocUnsafe(t),o=0;for(r=0;r<e.length;++r){var i=e[r];if(!f.isBuffer(i))throw new TypeError('"list" argument must be an Array of Buffers');i.copy(n,o),o+=i.length}return n},f.byteLength=p,f.prototype._isBuffer=!0,f.prototype.swap16=function(){var e=this.length;if(e%2!=0)throw new RangeError("Buffer size must be a multiple of 16-bits");for(var t=0;t<e;t+=2)h(this,t,t+1);return this},f.prototype.swap32=function(){var e=this.length;if(e%4!=0)throw new RangeError("Buffer size must be a multiple of 32-bits");for(var t=0;t<e;t+=4)h(this,t,t+3),h(this,t+1,t+2);return this},f.prototype.swap64=function(){var e=this.length;if(e%8!=0)throw new RangeError("Buffer size must be a multiple of 64-bits");for(var t=0;t<e;t+=8)h(this,t,t+7),h(this,t+1,t+6),h(this,t+2,t+5),h(this,t+3,t+4);return this},f.prototype.toString=function(){var e=0|this.length;return 0==e?"":0===arguments.length?_(this,0,e):function(e,t,r){var n=!1;if((void 0===t||t<0)&&(t=0),t>this.length)return"";if((void 0===r||r>this.length)&&(r=this.length),r<=0)return"";if((r>>>=0)<=(t>>>=0))return"";for(e=e||"utf8";;)switch(e){case"hex":return j(this,t,r);case"utf8":case"utf-8":return _(this,t,r);case"ascii":return E(this,t,r);case"latin1":case"binary":return x(this,t,r);case"base64":return v(this,t,r);case"ucs2":case"ucs-2":case"utf16le":case"utf-16le":return S(this,t,r);default:if(n)throw new TypeError("Unknown encoding: "+e);e=(e+"").toLowerCase(),n=!0}}.apply(this,arguments)},f.prototype.equals=function(e){if(!f.isBuffer(e))throw new TypeError("Argument must be a Buffer");return this===e||0===f.compare(this,e)},f.prototype.inspect=function(){var e="",t=I.INSPECT_MAX_BYTES;return 0<this.length&&(e=this.toString("hex",0,t).match(/.{2}/g).join(" "),this.length>t&&(e+=" ... ")),"<Buffer "+e+">"},f.prototype.compare=function(e,t,r,n,o){if(!f.isBuffer(e))throw new TypeError("Argument must be a Buffer");if(void 0===t&&(t=0),void 0===r&&(r=e?e.length:0),void 0===n&&(n=0),void 0===o&&(o=this.length),t<0||r>e.length||n<0||o>this.length)throw new RangeError("out of range index");if(o<=n&&r<=t)return 0;if(o<=n)return-1;if(r<=t)return 1;if(this===e)return 0;for(var i=(o>>>=0)-(n>>>=0),s=(r>>>=0)-(t>>>=0),a=Math.min(i,s),u=this.slice(n,o),d=e.slice(t,r),l=0;l<a;++l)if(u[l]!==d[l]){i=u[l],s=d[l];break}return i<s?-1:s<i?1:0},f.prototype.includes=function(e,t,r){return-1!==this.indexOf(e,t,r)},f.prototype.indexOf=function(e,t,r){return m(this,e,t,r,!0)},f.prototype.lastIndexOf=function(e,t,r){return m(this,e,t,r,!1)},f.prototype.write=function(e,t,r,n){if(void 0===t)n="utf8",r=this.length,t=0;else if(void 0===r&&"string"==typeof t)n=t,r=this.length,t=0;else{if(!isFinite(t))throw new Error("Buffer.write(string, encoding, offset[, length]) is no longer supported");t|=0,isFinite(r)?(r|=0,void 0===n&&(n="utf8")):(n=r,r=void 0)}var o=this.length-t;if((void 0===r||o<r)&&(r=o),0<e.length&&(r<0||t<0)||t>this.length)throw new RangeError("Attempt to write outside buffer bounds");n=n||"utf8";for(var i,s,a,u,d,l,f,c,p,h=!1;;)switch(n){case"hex":return b(this,e,t,r);case"utf8":case"utf-8":return c=t,p=r,C(B(e,(f=this).length-c),f,c,p);case"ascii":return g(this,e,t,r);case"latin1":case"binary":return g(this,e,t,r);case"base64":return u=this,d=t,l=r,C(q(e),u,d,l);case"ucs2":case"ucs-2":case"utf16le":case"utf-16le":return s=t,a=r,C(function(e,t){for(var r,n,o,i=[],s=0;s<e.length&&!((t-=2)<0);++s)r=e.charCodeAt(s),n=r>>8,o=r%256,i.push(o),i.push(n);return i}(e,(i=this).length-s),i,s,a);default:if(h)throw new TypeError("Unknown encoding: "+n);n=(""+n).toLowerCase(),h=!0}},f.prototype.toJSON=function(){return{type:"Buffer",data:Array.prototype.slice.call(this._arr||this,0)}};var w=4096;function E(e,t,r){var n="";r=Math.min(e.length,r);for(var o=t;o<r;++o)n+=String.fromCharCode(127&e[o]);return n}function x(e,t,r){var n="";r=Math.min(e.length,r);for(var o=t;o<r;++o)n+=String.fromCharCode(e[o]);return n}function j(e,t,r){var n=e.length;(!t||t<0)&&(t=0),(!r||r<0||n<r)&&(r=n);for(var o="",i=t;i<r;++i)o+=D(e[i]);return o}function S(e,t,r){for(var n=e.slice(t,r),o="",i=0;i<n.length;i+=2)o+=String.fromCharCode(n[i]+256*n[i+1]);return o}function A(e,t,r){if(e%1!=0||e<0)throw new RangeError("offset is not uint");if(r<e+t)throw new RangeError("Trying to access beyond buffer length")}function P(e,t,r,n,o,i){if(!f.isBuffer(e))throw new TypeError('"buffer" argument must be a Buffer instance');if(o<t||t<i)throw new RangeError('"value" argument is out of bounds');if(r+n>e.length)throw new RangeError("Index out of range")}function T(e,t,r,n){t<0&&(t=65535+t+1);for(var o=0,i=Math.min(e.length-r,2);o<i;++o)e[r+o]=(t&255<<8*(n?o:1-o))>>>8*(n?o:1-o)}function O(e,t,r,n){t<0&&(t=4294967295+t+1);for(var o=0,i=Math.min(e.length-r,4);o<i;++o)e[r+o]=t>>>8*(n?o:3-o)&255}function k(e,t,r,n){if(r+n>e.length)throw new RangeError("Index out of range");if(r<0)throw new RangeError("Index out of range")}function N(e,t,r,n,o){return o||k(e,0,r,4),i.write(e,t,r,n,23,4),r+4}function R(e,t,r,n,o){return o||k(e,0,r,8),i.write(e,t,r,n,52,8),r+8}f.prototype.slice=function(e,t){var r,n=this.length;if((e=~~e)<0?(e+=n)<0&&(e=0):n<e&&(e=n),(t=void 0===t?n:~~t)<0?(t+=n)<0&&(t=0):n<t&&(t=n),t<e&&(t=e),f.TYPED_ARRAY_SUPPORT)(r=this.subarray(e,t)).__proto__=f.prototype;else{var o=t-e;r=new f(o,void 0);for(var i=0;i<o;++i)r[i]=this[i+e]}return r},f.prototype.readUIntLE=function(e,t,r){e|=0,t|=0,r||A(e,t,this.length);for(var n=this[e],o=1,i=0;++i<t&&(o*=256);)n+=this[e+i]*o;return n},f.prototype.readUIntBE=function(e,t,r){e|=0,t|=0,r||A(e,t,this.length);for(var n=this[e+--t],o=1;0<t&&(o*=256);)n+=this[e+--t]*o;return n},f.prototype.readUInt8=function(e,t){return t||A(e,1,this.length),this[e]},f.prototype.readUInt16LE=function(e,t){return t||A(e,2,this.length),this[e]|this[e+1]<<8},f.prototype.readUInt16BE=function(e,t){return t||A(e,2,this.length),this[e]<<8|this[e+1]},f.prototype.readUInt32LE=function(e,t){return t||A(e,4,this.length),(this[e]|this[e+1]<<8|this[e+2]<<16)+16777216*this[e+3]},f.prototype.readUInt32BE=function(e,t){return t||A(e,4,this.length),16777216*this[e]+(this[e+1]<<16|this[e+2]<<8|this[e+3])},f.prototype.readIntLE=function(e,t,r){e|=0,t|=0,r||A(e,t,this.length);for(var n=this[e],o=1,i=0;++i<t&&(o*=256);)n+=this[e+i]*o;return(o*=128)<=n&&(n-=Math.pow(2,8*t)),n},f.prototype.readIntBE=function(e,t,r){e|=0,t|=0,r||A(e,t,this.length);for(var n=t,o=1,i=this[e+--n];0<n&&(o*=256);)i+=this[e+--n]*o;return(o*=128)<=i&&(i-=Math.pow(2,8*t)),i},f.prototype.readInt8=function(e,t){return t||A(e,1,this.length),128&this[e]?-1*(255-this[e]+1):this[e]},f.prototype.readInt16LE=function(e,t){t||A(e,2,this.length);var r=this[e]|this[e+1]<<8;return 32768&r?4294901760|r:r},f.prototype.readInt16BE=function(e,t){t||A(e,2,this.length);var r=this[e+1]|this[e]<<8;return 32768&r?4294901760|r:r},f.prototype.readInt32LE=function(e,t){return t||A(e,4,this.length),this[e]|this[e+1]<<8|this[e+2]<<16|this[e+3]<<24},f.prototype.readInt32BE=function(e,t){return t||A(e,4,this.length),this[e]<<24|this[e+1]<<16|this[e+2]<<8|this[e+3]},f.prototype.readFloatLE=function(e,t){return t||A(e,4,this.length),i.read(this,e,!0,23,4)},f.prototype.readFloatBE=function(e,t){return t||A(e,4,this.length),i.read(this,e,!1,23,4)},f.prototype.readDoubleLE=function(e,t){return t||A(e,8,this.length),i.read(this,e,!0,52,8)},f.prototype.readDoubleBE=function(e,t){return t||A(e,8,this.length),i.read(this,e,!1,52,8)},f.prototype.writeUIntLE=function(e,t,r,n){e=+e,t|=0,r|=0,n||P(this,e,t,r,Math.pow(2,8*r)-1,0);var o=1,i=0;for(this[t]=255&e;++i<r&&(o*=256);)this[t+i]=e/o&255;return t+r},f.prototype.writeUIntBE=function(e,t,r,n){e=+e,t|=0,r|=0,n||P(this,e,t,r,Math.pow(2,8*r)-1,0);var o=r-1,i=1;for(this[t+o]=255&e;0<=--o&&(i*=256);)this[t+o]=e/i&255;return t+r},f.prototype.writeUInt8=function(e,t,r){return e=+e,t|=0,r||P(this,e,t,1,255,0),f.TYPED_ARRAY_SUPPORT||(e=Math.floor(e)),this[t]=255&e,t+1},f.prototype.writeUInt16LE=function(e,t,r){return e=+e,t|=0,r||P(this,e,t,2,65535,0),f.TYPED_ARRAY_SUPPORT?(this[t]=255&e,this[t+1]=e>>>8):T(this,e,t,!0),t+2},f.prototype.writeUInt16BE=function(e,t,r){return e=+e,t|=0,r||P(this,e,t,2,65535,0),f.TYPED_ARRAY_SUPPORT?(this[t]=e>>>8,this[t+1]=255&e):T(this,e,t,!1),t+2},f.prototype.writeUInt32LE=function(e,t,r){return e=+e,t|=0,r||P(this,e,t,4,4294967295,0),f.TYPED_ARRAY_SUPPORT?(this[t+3]=e>>>24,this[t+2]=e>>>16,this[t+1]=e>>>8,this[t]=255&e):O(this,e,t,!0),t+4},f.prototype.writeUInt32BE=function(e,t,r){return e=+e,t|=0,r||P(this,e,t,4,4294967295,0),f.TYPED_ARRAY_SUPPORT?(this[t]=e>>>24,this[t+1]=e>>>16,this[t+2]=e>>>8,this[t+3]=255&e):O(this,e,t,!1),t+4},f.prototype.writeIntLE=function(e,t,r,n){if(e=+e,t|=0,!n){var o=Math.pow(2,8*r-1);P(this,e,t,r,o-1,-o)}var i=0,s=1,a=0;for(this[t]=255&e;++i<r&&(s*=256);)e<0&&0===a&&0!==this[t+i-1]&&(a=1),this[t+i]=(e/s>>0)-a&255;return t+r},f.prototype.writeIntBE=function(e,t,r,n){if(e=+e,t|=0,!n){var o=Math.pow(2,8*r-1);P(this,e,t,r,o-1,-o)}var i=r-1,s=1,a=0;for(this[t+i]=255&e;0<=--i&&(s*=256);)e<0&&0===a&&0!==this[t+i+1]&&(a=1),this[t+i]=(e/s>>0)-a&255;return t+r},f.prototype.writeInt8=function(e,t,r){return e=+e,t|=0,r||P(this,e,t,1,127,-128),f.TYPED_ARRAY_SUPPORT||(e=Math.floor(e)),e<0&&(e=255+e+1),this[t]=255&e,t+1},f.prototype.writeInt16LE=function(e,t,r){return e=+e,t|=0,r||P(this,e,t,2,32767,-32768),f.TYPED_ARRAY_SUPPORT?(this[t]=255&e,this[t+1]=e>>>8):T(this,e,t,!0),t+2},f.prototype.writeInt16BE=function(e,t,r){return e=+e,t|=0,r||P(this,e,t,2,32767,-32768),f.TYPED_ARRAY_SUPPORT?(this[t]=e>>>8,this[t+1]=255&e):T(this,e,t,!1),t+2},f.prototype.writeInt32LE=function(e,t,r){return e=+e,t|=0,r||P(this,e,t,4,2147483647,-2147483648),f.TYPED_ARRAY_SUPPORT?(this[t]=255&e,this[t+1]=e>>>8,this[t+2]=e>>>16,this[t+3]=e>>>24):O(this,e,t,!0),t+4},f.prototype.writeInt32BE=function(e,t,r){return e=+e,t|=0,r||P(this,e,t,4,2147483647,-2147483648),e<0&&(e=4294967295+e+1),f.TYPED_ARRAY_SUPPORT?(this[t]=e>>>24,this[t+1]=e>>>16,this[t+2]=e>>>8,this[t+3]=255&e):O(this,e,t,!1),t+4},f.prototype.writeFloatLE=function(e,t,r){return N(this,e,t,!0,r)},f.prototype.writeFloatBE=function(e,t,r){return N(this,e,t,!1,r)},f.prototype.writeDoubleLE=function(e,t,r){return R(this,e,t,!0,r)},f.prototype.writeDoubleBE=function(e,t,r){return R(this,e,t,!1,r)},f.prototype.copy=function(e,t,r,n){if(r=r||0,n||0===n||(n=this.length),t>=e.length&&(t=e.length),t=t||0,0<n&&n<r&&(n=r),n===r)return 0;if(0===e.length||0===this.length)return 0;if(t<0)throw new RangeError("targetStart out of bounds");if(r<0||r>=this.length)throw new RangeError("sourceStart out of bounds");if(n<0)throw new RangeError("sourceEnd out of bounds");n>this.length&&(n=this.length),e.length-t<n-r&&(n=e.length-t+r);var o,i=n-r;if(this===e&&r<t&&t<n)for(o=i-1;0<=o;--o)e[o+t]=this[o+r];else if(i<1e3||!f.TYPED_ARRAY_SUPPORT)for(o=0;o<i;++o)e[o+t]=this[o+r];else Uint8Array.prototype.set.call(e,this.subarray(r,r+i),t);return i},f.prototype.fill=function(e,t,r,n){if("string"==typeof e){if("string"==typeof t?(n=t,t=0,r=this.length):"string"==typeof r&&(n=r,r=this.length),1===e.length){var o=e.charCodeAt(0);o<256&&(e=o)}if(void 0!==n&&"string"!=typeof n)throw new TypeError("encoding must be a string");if("string"==typeof n&&!f.isEncoding(n))throw new TypeError("Unknown encoding: "+n)}else"number"==typeof e&&(e&=255);if(t<0||this.length<t||this.length<r)throw new RangeError("Out of range index");if(r<=t)return this;var i;if(t>>>=0,r=void 0===r?this.length:r>>>0,"number"==typeof(e=e||0))for(i=t;i<r;++i)this[i]=e;else{var s=f.isBuffer(e)?e:B(new f(e,n).toString()),a=s.length;for(i=0;i<r-t;++i)this[i+t]=s[i%a]}return this};var t=/[^+\/0-9A-Za-z-_]/g;function D(e){return e<16?"0"+e.toString(16):e.toString(16)}function B(e,t){var r;t=t||1/0;for(var n=e.length,o=null,i=[],s=0;s<n;++s){if(55295<(r=e.charCodeAt(s))&&r<57344){if(!o){if(56319<r){-1<(t-=3)&&i.push(239,191,189);continue}if(s+1===n){-1<(t-=3)&&i.push(239,191,189);continue}o=r;continue}if(r<56320){-1<(t-=3)&&i.push(239,191,189),o=r;continue}r=65536+(o-55296<<10|r-56320)}else o&&-1<(t-=3)&&i.push(239,191,189);if(o=null,r<128){if((t-=1)<0)break;i.push(r)}else if(r<2048){if((t-=2)<0)break;i.push(r>>6|192,63&r|128)}else if(r<65536){if((t-=3)<0)break;i.push(r>>12|224,r>>6&63|128,63&r|128)}else{if(!(r<1114112))throw new Error("Invalid code point");if((t-=4)<0)break;i.push(r>>18|240,r>>12&63|128,r>>6&63|128,63&r|128)}}return i}function q(e){return n.toByteArray(function(e){if((e=function(e){return e.trim?e.trim():e.replace(/^\s+|\s+$/g,"")}(e).replace(t,"")).length<2)return"";for(;e.length%4!=0;)e+="=";return e}(e))}function C(e,t,r,n){for(var o=0;o<n&&!(o+r>=t.length||o>=e.length);++o)t[o+r]=e[o];return o}}).call(this,U(/*! ./../webpack/buildin/global.js */"./node_modules/webpack/buildin/global.js"))},"./node_modules/core-util-is/lib/util.js":
/*!***********************************************!*\
  !*** ./node_modules/core-util-is/lib/util.js ***!
  \***********************************************/
/*! no static exports found */function(e,r,t){(function(e){function t(e){return Object.prototype.toString.call(e)}r.isArray=function(e){return Array.isArray?Array.isArray(e):"[object Array]"===t(e)},r.isBoolean=function(e){return"boolean"==typeof e},r.isNull=function(e){return null===e},r.isNullOrUndefined=function(e){return null==e},r.isNumber=function(e){return"number"==typeof e},r.isString=function(e){return"string"==typeof e},r.isSymbol=function(e){return"symbol"==typeof e},r.isUndefined=function(e){return void 0===e},r.isRegExp=function(e){return"[object RegExp]"===t(e)},r.isObject=function(e){return"object"==typeof e&&null!==e},r.isDate=function(e){return"[object Date]"===t(e)},r.isError=function(e){return"[object Error]"===t(e)||e instanceof Error},r.isFunction=function(e){return"function"==typeof e},r.isPrimitive=function(e){return null===e||"boolean"==typeof e||"number"==typeof e||"string"==typeof e||"symbol"==typeof e||void 0===e},r.isBuffer=e.isBuffer}).call(this,t(/*! ./../../buffer/index.js */"./node_modules/buffer/index.js").Buffer)},"./node_modules/deep-equal/index.js":
/*!******************************************!*\
  !*** ./node_modules/deep-equal/index.js ***!
  \******************************************/
/*! no static exports found */function(e,t,r){var a=Array.prototype.slice,u=r(/*! ./lib/keys.js */"./node_modules/deep-equal/lib/keys.js"),d=r(/*! ./lib/is_arguments.js */"./node_modules/deep-equal/lib/is_arguments.js"),l=e.exports=function(e,t,r){return r=r||{},e===t||(e instanceof Date&&t instanceof Date?e.getTime()===t.getTime():!e||!t||"object"!=typeof e&&"object"!=typeof t?r.strict?e===t:e==t:function(e,t,r){var n,o;if(f(e)||f(t))return!1;if(e.prototype!==t.prototype)return!1;if(d(e))return!!d(t)&&(e=a.call(e),t=a.call(t),l(e,t,r));if(c(e)){if(!c(t))return!1;if(e.length!==t.length)return!1;for(n=0;n<e.length;n++)if(e[n]!==t[n])return!1;return!0}try{var i=u(e),s=u(t)}catch(e){return!1}if(i.length!=s.length)return!1;for(i.sort(),s.sort(),n=i.length-1;0<=n;n--)if(i[n]!=s[n])return!1;for(n=i.length-1;0<=n;n--)if(o=i[n],!l(e[o],t[o],r))return!1;return typeof e==typeof t}(e,t,r))};function f(e){return null==e}function c(e){return!(!e||"object"!=typeof e||"number"!=typeof e.length)&&("function"==typeof e.copy&&"function"==typeof e.slice&&!(0<e.length&&"number"!=typeof e[0]))}},"./node_modules/deep-equal/lib/is_arguments.js":
/*!*****************************************************!*\
  !*** ./node_modules/deep-equal/lib/is_arguments.js ***!
  \*****************************************************/
/*! no static exports found */function(e,t){var r="[object Arguments]"==function(){return Object.prototype.toString.call(arguments)}();function n(e){return"[object Arguments]"==Object.prototype.toString.call(e)}function o(e){return e&&"object"==typeof e&&"number"==typeof e.length&&Object.prototype.hasOwnProperty.call(e,"callee")&&!Object.prototype.propertyIsEnumerable.call(e,"callee")||!1}(t=e.exports=r?n:o).supported=n,t.unsupported=o},"./node_modules/deep-equal/lib/keys.js":
/*!*********************************************!*\
  !*** ./node_modules/deep-equal/lib/keys.js ***!
  \*********************************************/
/*! no static exports found */function(e,t){function r(e){var t=[];for(var r in e)t.push(r);return t}(e.exports="function"==typeof Object.keys?Object.keys:r).shim=r},"./node_modules/define-properties/index.js":
/*!*************************************************!*\
  !*** ./node_modules/define-properties/index.js ***!
  \*************************************************/
/*! no static exports found */function(e,t,r){"use strict";function i(e,t,r,n){t in e&&(!function(e){return"function"==typeof e&&"[object Function]"===o.call(e)}(n)||!n())||(l?d(e,t,{configurable:!0,enumerable:!1,value:r,writable:!0}):e[t]=r)}function n(e,t){var r=2<arguments.length?arguments[2]:{},n=s(t);a&&(n=u.call(n,Object.getOwnPropertySymbols(t)));for(var o=0;o<n.length;o+=1)i(e,n[o],t[n[o]],r[n[o]])}var s=r(/*! object-keys */"./node_modules/object-keys/index.js"),a="function"==typeof Symbol&&"symbol"==typeof Symbol("foo"),o=Object.prototype.toString,u=Array.prototype.concat,d=Object.defineProperty,l=d&&function(){var e={};try{for(var t in d(e,"x",{enumerable:!1,value:e}),e)return!1;return e.x===e}catch(e){return!1}}();n.supportsDescriptors=!!l,e.exports=n},"./node_modules/es-abstract/GetIntrinsic.js":
/*!**************************************************!*\
  !*** ./node_modules/es-abstract/GetIntrinsic.js ***!
  \**************************************************/
/*! no static exports found */function(e,t,r){"use strict";var n,o=Object.getOwnPropertyDescriptor?function(){return Object.getOwnPropertyDescriptor(arguments,"callee").get}():function(){throw new TypeError},i="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator,s=Object.getPrototypeOf||function(e){return e.__proto__},a=n,u=n,d=n,l=n,f="undefined"==typeof Uint8Array?n:s(Uint8Array),c={"$ %Array%":Array,"$ %ArrayBuffer%":"undefined"==typeof ArrayBuffer?n:ArrayBuffer,"$ %ArrayBufferPrototype%":"undefined"==typeof ArrayBuffer?n:ArrayBuffer.prototype,"$ %ArrayIteratorPrototype%":i?s([][Symbol.iterator]()):n,"$ %ArrayPrototype%":Array.prototype,"$ %ArrayProto_entries%":Array.prototype.entries,"$ %ArrayProto_forEach%":Array.prototype.forEach,"$ %ArrayProto_keys%":Array.prototype.keys,"$ %ArrayProto_values%":Array.prototype.values,"$ %AsyncFromSyncIteratorPrototype%":n,"$ %AsyncFunction%":u,"$ %AsyncFunctionPrototype%":n,"$ %AsyncGenerator%":n,"$ %AsyncGeneratorFunction%":d,"$ %AsyncGeneratorPrototype%":n,"$ %AsyncIteratorPrototype%":l&&i&&Symbol.asyncIterator?l[Symbol.asyncIterator]():n,"$ %Atomics%":"undefined"==typeof Atomics?n:Atomics,"$ %Boolean%":Boolean,"$ %BooleanPrototype%":Boolean.prototype,"$ %DataView%":"undefined"==typeof DataView?n:DataView,"$ %DataViewPrototype%":"undefined"==typeof DataView?n:DataView.prototype,"$ %Date%":Date,"$ %DatePrototype%":Date.prototype,"$ %decodeURI%":decodeURI,"$ %decodeURIComponent%":decodeURIComponent,"$ %encodeURI%":encodeURI,"$ %encodeURIComponent%":encodeURIComponent,"$ %Error%":Error,"$ %ErrorPrototype%":Error.prototype,"$ %eval%":eval,"$ %EvalError%":EvalError,"$ %EvalErrorPrototype%":EvalError.prototype,"$ %Float32Array%":"undefined"==typeof Float32Array?n:Float32Array,"$ %Float32ArrayPrototype%":"undefined"==typeof Float32Array?n:Float32Array.prototype,"$ %Float64Array%":"undefined"==typeof Float64Array?n:Float64Array,"$ %Float64ArrayPrototype%":"undefined"==typeof Float64Array?n:Float64Array.prototype,"$ %Function%":Function,"$ %FunctionPrototype%":Function.prototype,"$ %Generator%":n,"$ %GeneratorFunction%":a,"$ %GeneratorPrototype%":n,"$ %Int8Array%":"undefined"==typeof Int8Array?n:Int8Array,"$ %Int8ArrayPrototype%":"undefined"==typeof Int8Array?n:Int8Array.prototype,"$ %Int16Array%":"undefined"==typeof Int16Array?n:Int16Array,"$ %Int16ArrayPrototype%":"undefined"==typeof Int16Array?n:Int8Array.prototype,"$ %Int32Array%":"undefined"==typeof Int32Array?n:Int32Array,"$ %Int32ArrayPrototype%":"undefined"==typeof Int32Array?n:Int32Array.prototype,"$ %isFinite%":isFinite,"$ %isNaN%":isNaN,"$ %IteratorPrototype%":i?s(s([][Symbol.iterator]())):n,"$ %JSON%":JSON,"$ %JSONParse%":JSON.parse,"$ %Map%":"undefined"==typeof Map?n:Map,"$ %MapIteratorPrototype%":"undefined"!=typeof Map&&i?s((new Map)[Symbol.iterator]()):n,"$ %MapPrototype%":"undefined"==typeof Map?n:Map.prototype,"$ %Math%":Math,"$ %Number%":Number,"$ %NumberPrototype%":Number.prototype,"$ %Object%":Object,"$ %ObjectPrototype%":Object.prototype,"$ %ObjProto_toString%":Object.prototype.toString,"$ %ObjProto_valueOf%":Object.prototype.valueOf,"$ %parseFloat%":parseFloat,"$ %parseInt%":parseInt,"$ %Promise%":"undefined"==typeof Promise?n:Promise,"$ %PromisePrototype%":"undefined"==typeof Promise?n:Promise.prototype,"$ %PromiseProto_then%":"undefined"==typeof Promise?n:Promise.prototype.then,"$ %Promise_all%":"undefined"==typeof Promise?n:Promise.all,"$ %Promise_reject%":"undefined"==typeof Promise?n:Promise.reject,"$ %Promise_resolve%":"undefined"==typeof Promise?n:Promise.resolve,"$ %Proxy%":"undefined"==typeof Proxy?n:Proxy,"$ %RangeError%":RangeError,"$ %RangeErrorPrototype%":RangeError.prototype,"$ %ReferenceError%":ReferenceError,"$ %ReferenceErrorPrototype%":ReferenceError.prototype,"$ %Reflect%":"undefined"==typeof Reflect?n:Reflect,"$ %RegExp%":RegExp,"$ %RegExpPrototype%":RegExp.prototype,"$ %Set%":"undefined"==typeof Set?n:Set,"$ %SetIteratorPrototype%":"undefined"!=typeof Set&&i?s((new Set)[Symbol.iterator]()):n,"$ %SetPrototype%":"undefined"==typeof Set?n:Set.prototype,"$ %SharedArrayBuffer%":"undefined"==typeof SharedArrayBuffer?n:SharedArrayBuffer,"$ %SharedArrayBufferPrototype%":"undefined"==typeof SharedArrayBuffer?n:SharedArrayBuffer.prototype,"$ %String%":String,"$ %StringIteratorPrototype%":i?s(""[Symbol.iterator]()):n,"$ %StringPrototype%":String.prototype,"$ %Symbol%":i?Symbol:n,"$ %SymbolPrototype%":i?Symbol.prototype:n,"$ %SyntaxError%":SyntaxError,"$ %SyntaxErrorPrototype%":SyntaxError.prototype,"$ %ThrowTypeError%":o,"$ %TypedArray%":f,"$ %TypedArrayPrototype%":f?f.prototype:n,"$ %TypeError%":TypeError,"$ %TypeErrorPrototype%":TypeError.prototype,"$ %Uint8Array%":"undefined"==typeof Uint8Array?n:Uint8Array,"$ %Uint8ArrayPrototype%":"undefined"==typeof Uint8Array?n:Uint8Array.prototype,"$ %Uint8ClampedArray%":"undefined"==typeof Uint8ClampedArray?n:Uint8ClampedArray,"$ %Uint8ClampedArrayPrototype%":"undefined"==typeof Uint8ClampedArray?n:Uint8ClampedArray.prototype,"$ %Uint16Array%":"undefined"==typeof Uint16Array?n:Uint16Array,"$ %Uint16ArrayPrototype%":"undefined"==typeof Uint16Array?n:Uint16Array.prototype,"$ %Uint32Array%":"undefined"==typeof Uint32Array?n:Uint32Array,"$ %Uint32ArrayPrototype%":"undefined"==typeof Uint32Array?n:Uint32Array.prototype,"$ %URIError%":URIError,"$ %URIErrorPrototype%":URIError.prototype,"$ %WeakMap%":"undefined"==typeof WeakMap?n:WeakMap,"$ %WeakMapPrototype%":"undefined"==typeof WeakMap?n:WeakMap.prototype,"$ %WeakSet%":"undefined"==typeof WeakSet?n:WeakSet,"$ %WeakSetPrototype%":"undefined"==typeof WeakSet?n:WeakSet.prototype};e.exports=function(e,t){if(1<arguments.length&&"boolean"!=typeof t)throw new TypeError('"allowMissing" argument must be a boolean');var r="$ "+e;if(!(r in c))throw new SyntaxError("intrinsic "+e+" does not exist!");if(void 0===c[r]&&!t)throw new TypeError("intrinsic "+e+" exists, but is not available. Please file an issue!");return c[r]}},"./node_modules/es-abstract/es5.js":
/*!*****************************************!*\
  !*** ./node_modules/es-abstract/es5.js ***!
  \*****************************************/
/*! no static exports found */function(e,t,r){"use strict";function a(e,t){return e===t||!(e.length>t.length)&&g(t,0,e.length)===e}var n=r(/*! ./GetIntrinsic */"./node_modules/es-abstract/GetIntrinsic.js"),o=n("%Object%"),u=n("%TypeError%"),i=n("%String%"),d=n("%Number%"),s=r(/*! ./helpers/assertRecord */"./node_modules/es-abstract/helpers/assertRecord.js"),l=r(/*! ./helpers/isPropertyDescriptor */"./node_modules/es-abstract/helpers/isPropertyDescriptor.js"),f=r(/*! ./helpers/isNaN */"./node_modules/es-abstract/helpers/isNaN.js"),c=r(/*! ./helpers/isFinite */"./node_modules/es-abstract/helpers/isFinite.js"),p=r(/*! ./helpers/sign */"./node_modules/es-abstract/helpers/sign.js"),h=r(/*! ./helpers/mod */"./node_modules/es-abstract/helpers/mod.js"),m=r(/*! is-callable */"./node_modules/is-callable/index.js"),y=r(/*! es-to-primitive/es5 */"./node_modules/es-to-primitive/es5.js"),b=r(/*! has */"./node_modules/has/src/index.js"),g=r(/*! ./helpers/callBind */"./node_modules/es-abstract/helpers/callBind.js")(i.prototype.slice),v={ToPrimitive:y,ToBoolean:function(e){return!!e},ToNumber:function(e){return+e},ToInteger:function(e){var t=this.ToNumber(e);return f(t)?0:0!==t&&c(t)?p(t)*Math.floor(Math.abs(t)):t},ToInt32:function(e){return this.ToNumber(e)>>0},ToUint32:function(e){return this.ToNumber(e)>>>0},ToUint16:function(e){var t=this.ToNumber(e);if(f(t)||0===t||!c(t))return 0;var r=p(t)*Math.floor(Math.abs(t));return h(r,65536)},ToString:function(e){return i(e)},ToObject:function(e){return this.CheckObjectCoercible(e),o(e)},CheckObjectCoercible:function(e,t){if(null==e)throw new u(t||"Cannot call method on "+e);return e},IsCallable:m,SameValue:function(e,t){return e===t?0!==e||1/e==1/t:f(e)&&f(t)},Type:function(e){return null===e?"Null":void 0===e?"Undefined":"function"==typeof e||"object"==typeof e?"Object":"number"==typeof e?"Number":"boolean"==typeof e?"Boolean":"string"==typeof e?"String":void 0},IsPropertyDescriptor:function(e){return l(this,e)},IsAccessorDescriptor:function(e){return void 0!==e&&(s(this,"Property Descriptor","Desc",e),!(!b(e,"[[Get]]")&&!b(e,"[[Set]]")))},IsDataDescriptor:function(e){return void 0!==e&&(s(this,"Property Descriptor","Desc",e),!(!b(e,"[[Value]]")&&!b(e,"[[Writable]]")))},IsGenericDescriptor:function(e){return void 0!==e&&(s(this,"Property Descriptor","Desc",e),!this.IsAccessorDescriptor(e)&&!this.IsDataDescriptor(e))},FromPropertyDescriptor:function(e){if(void 0===e)return e;if(s(this,"Property Descriptor","Desc",e),this.IsDataDescriptor(e))return{value:e["[[Value]]"],writable:!!e["[[Writable]]"],enumerable:!!e["[[Enumerable]]"],configurable:!!e["[[Configurable]]"]};if(this.IsAccessorDescriptor(e))return{get:e["[[Get]]"],set:e["[[Set]]"],enumerable:!!e["[[Enumerable]]"],configurable:!!e["[[Configurable]]"]};throw new u("FromPropertyDescriptor must be called with a fully populated Property Descriptor")},ToPropertyDescriptor:function(e){if("Object"!==this.Type(e))throw new u("ToPropertyDescriptor requires an object");var t={};if(b(e,"enumerable")&&(t["[[Enumerable]]"]=this.ToBoolean(e.enumerable)),b(e,"configurable")&&(t["[[Configurable]]"]=this.ToBoolean(e.configurable)),b(e,"value")&&(t["[[Value]]"]=e.value),b(e,"writable")&&(t["[[Writable]]"]=this.ToBoolean(e.writable)),b(e,"get")){var r=e.get;if(void 0!==r&&!this.IsCallable(r))throw new TypeError("getter must be a function");t["[[Get]]"]=r}if(b(e,"set")){var n=e.set;if(void 0!==n&&!this.IsCallable(n))throw new u("setter must be a function");t["[[Set]]"]=n}if((b(t,"[[Get]]")||b(t,"[[Set]]"))&&(b(t,"[[Value]]")||b(t,"[[Writable]]")))throw new u("Invalid property descriptor. Cannot both specify accessors and a value or writable attribute");return t},"Abstract Equality Comparison":function(e,t){var r=this.Type(e),n=this.Type(t);return r===n?e===t:null==e&&null==t||("Number"===r&&"String"===n?this["Abstract Equality Comparison"](e,this.ToNumber(t)):"String"===r&&"Number"===n?this["Abstract Equality Comparison"](this.ToNumber(e),t):"Boolean"===r?this["Abstract Equality Comparison"](this.ToNumber(e),t):"Boolean"===n?this["Abstract Equality Comparison"](e,this.ToNumber(t)):"String"!==r&&"Number"!==r||"Object"!==n?"Object"===r&&("String"===n||"Number"===n)&&this["Abstract Equality Comparison"](this.ToPrimitive(e),t):this["Abstract Equality Comparison"](e,this.ToPrimitive(t)))},"Strict Equality Comparison":function(e,t){var r=this.Type(e);return r===this.Type(t)&&("Undefined"===r||"Null"===r||e===t)},"Abstract Relational Comparison":function(e,t,r){if("Boolean"!==this.Type(r))throw new u("Assertion failed: LeftFirst argument must be a Boolean");var n,o;if(r?(n=this.ToPrimitive(e,d),o=this.ToPrimitive(t,d)):(o=this.ToPrimitive(t,d),n=this.ToPrimitive(e,d)),"String"===this.Type(n)&&"String"===this.Type(o))return!a(o,n)&&(!!a(n,o)||n<o);var i=this.ToNumber(n),s=this.ToNumber(o);return f(i)||f(s)?void 0:(!c(i)||!c(s)||i!==s)&&((0!==i||0!==s)&&(i!==1/0&&(s===1/0||s!==-1/0&&(i===-1/0||i<s))))}};e.exports=v},"./node_modules/es-abstract/helpers/assertRecord.js":
/*!**********************************************************!*\
  !*** ./node_modules/es-abstract/helpers/assertRecord.js ***!
  \**********************************************************/
/*! no static exports found */function(e,t,r){"use strict";var n=r(/*! ../GetIntrinsic */"./node_modules/es-abstract/GetIntrinsic.js"),s=n("%TypeError%"),i=n("%SyntaxError%"),a=r(/*! has */"./node_modules/has/src/index.js"),u={"Property Descriptor":function(e,t){if("Object"!==e.Type(t))return!1;var r={"[[Configurable]]":!0,"[[Enumerable]]":!0,"[[Get]]":!0,"[[Set]]":!0,"[[Value]]":!0,"[[Writable]]":!0};for(var n in t)if(a(t,n)&&!r[n])return!1;var o=a(t,"[[Value]]"),i=a(t,"[[Get]]")||a(t,"[[Set]]");if(o&&i)throw new s("Property Descriptors may not be both accessor and data descriptors");return!0}};e.exports=function(e,t,r,n){var o=u[t];if("function"!=typeof o)throw new i("unknown record type: "+t);if(!o(e,n))throw new s(r+" must be a "+t)}},"./node_modules/es-abstract/helpers/callBind.js":
/*!******************************************************!*\
  !*** ./node_modules/es-abstract/helpers/callBind.js ***!
  \******************************************************/
/*! no static exports found */function(e,t,r){"use strict";var n=r(/*! function-bind */"./node_modules/function-bind/index.js"),o=r(/*! ../GetIntrinsic */"./node_modules/es-abstract/GetIntrinsic.js")("%Function%"),i=o.apply,s=o.call;e.exports=function(){return n.apply(s,arguments)},e.exports.apply=function(){return n.apply(i,arguments)}},"./node_modules/es-abstract/helpers/isFinite.js":
/*!******************************************************!*\
  !*** ./node_modules/es-abstract/helpers/isFinite.js ***!
  \******************************************************/
/*! no static exports found */function(e,t,r){"use strict";var n=Number.isNaN||function(e){return e!=e};e.exports=Number.isFinite||function(e){return"number"==typeof e&&!n(e)&&e!==1/0&&e!==-1/0}},"./node_modules/es-abstract/helpers/isNaN.js":
/*!***************************************************!*\
  !*** ./node_modules/es-abstract/helpers/isNaN.js ***!
  \***************************************************/
/*! no static exports found */function(e,t,r){"use strict";e.exports=Number.isNaN||function(e){return e!=e}},"./node_modules/es-abstract/helpers/isPropertyDescriptor.js":
/*!******************************************************************!*\
  !*** ./node_modules/es-abstract/helpers/isPropertyDescriptor.js ***!
  \******************************************************************/
/*! no static exports found */function(e,t,r){"use strict";var n=r(/*! ../GetIntrinsic */"./node_modules/es-abstract/GetIntrinsic.js"),o=r(/*! has */"./node_modules/has/src/index.js"),i=n("%TypeError%");e.exports=function(e,t){if("Object"!==e.Type(t))return!1;var r={"[[Configurable]]":!0,"[[Enumerable]]":!0,"[[Get]]":!0,"[[Set]]":!0,"[[Value]]":!0,"[[Writable]]":!0};for(var n in t)if(o(t,n)&&!r[n])return!1;if(e.IsDataDescriptor(t)&&e.IsAccessorDescriptor(t))throw new i("Property Descriptors may not be both accessor and data descriptors");return!0}},"./node_modules/es-abstract/helpers/mod.js":
/*!*************************************************!*\
  !*** ./node_modules/es-abstract/helpers/mod.js ***!
  \*************************************************/
/*! no static exports found */function(e,t,r){"use strict";e.exports=function(e,t){var r=e%t;return Math.floor(0<=r?r:r+t)}},"./node_modules/es-abstract/helpers/sign.js":
/*!**************************************************!*\
  !*** ./node_modules/es-abstract/helpers/sign.js ***!
  \**************************************************/
/*! no static exports found */function(e,t,r){"use strict";e.exports=function(e){return 0<=e?1:-1}},"./node_modules/es-to-primitive/es5.js":
/*!*********************************************!*\
  !*** ./node_modules/es-to-primitive/es5.js ***!
  \*********************************************/
/*! no static exports found */function(e,t,r){"use strict";var i=Object.prototype.toString,s=r(/*! ./helpers/isPrimitive */"./node_modules/es-to-primitive/helpers/isPrimitive.js"),a=r(/*! is-callable */"./node_modules/is-callable/index.js"),n=function(e){var t;if((t=1<arguments.length?arguments[1]:"[object Date]"===i.call(e)?String:Number)!==String&&t!==Number)throw new TypeError("invalid [[DefaultValue]] hint supplied");var r,n,o=t===String?["toString","valueOf"]:["valueOf","toString"];for(n=0;n<o.length;++n)if(a(e[o[n]])&&(r=e[o[n]](),s(r)))return r;throw new TypeError("No default value")};e.exports=function(e,t){return s(e)?e:1<arguments.length?n(e,t):n(e)}},"./node_modules/es-to-primitive/helpers/isPrimitive.js":
/*!*************************************************************!*\
  !*** ./node_modules/es-to-primitive/helpers/isPrimitive.js ***!
  \*************************************************************/
/*! no static exports found */function(e,t){e.exports=function(e){return null===e||"function"!=typeof e&&"object"!=typeof e}},"./node_modules/events/events.js":
/*!***************************************!*\
  !*** ./node_modules/events/events.js ***!
  \***************************************/
/*! no static exports found */function(e,t,r){"use strict";var n,o="object"==typeof Reflect?Reflect:null,l=o&&"function"==typeof o.apply?o.apply:function(e,t,r){return Function.prototype.apply.call(e,t,r)};n=o&&"function"==typeof o.ownKeys?o.ownKeys:Object.getOwnPropertySymbols?function(e){return Object.getOwnPropertyNames(e).concat(Object.getOwnPropertySymbols(e))}:function(e){return Object.getOwnPropertyNames(e)};var i=Number.isNaN||function(e){return e!=e};function s(){s.init.call(this)}((e.exports=s).EventEmitter=s).prototype._events=void 0,s.prototype._eventsCount=0,s.prototype._maxListeners=void 0;var a=10;function u(e){return void 0===e._maxListeners?s.defaultMaxListeners:e._maxListeners}function d(e,t,r,n){var o,i,s;if("function"!=typeof r)throw new TypeError('The "listener" argument must be of type Function. Received type '+typeof r);if(void 0===(i=e._events)?(i=e._events=Object.create(null),e._eventsCount=0):(void 0!==i.newListener&&(e.emit("newListener",t,r.listener?r.listener:r),i=e._events),s=i[t]),void 0===s)s=i[t]=r,++e._eventsCount;else if("function"==typeof s?s=i[t]=n?[r,s]:[s,r]:n?s.unshift(r):s.push(r),0<(o=u(e))&&s.length>o&&!s.warned){s.warned=!0;var a=new Error("Possible EventEmitter memory leak detected. "+s.length+" "+String(t)+" listeners added. Use emitter.setMaxListeners() to increase limit");a.name="MaxListenersExceededWarning",a.emitter=e,a.type=t,a.count=s.length,function(e){console&&console.warn&&console.warn(e)}(a)}return e}function f(e,t,r){var n={fired:!1,wrapFn:void 0,target:e,type:t,listener:r},o=function(){for(var e=[],t=0;t<arguments.length;t++)e.push(arguments[t]);this.fired||(this.target.removeListener(this.type,this.wrapFn),this.fired=!0,l(this.listener,this.target,e))}.bind(n);return o.listener=r,n.wrapFn=o}function c(e,t,r){var n=e._events;if(void 0===n)return[];var o=n[t];return void 0===o?[]:"function"==typeof o?r?[o.listener||o]:[o]:r?function(e){for(var t=new Array(e.length),r=0;r<t.length;++r)t[r]=e[r].listener||e[r];return t}(o):h(o,o.length)}function p(e){var t=this._events;if(void 0!==t){var r=t[e];if("function"==typeof r)return 1;if(void 0!==r)return r.length}return 0}function h(e,t){for(var r=new Array(t),n=0;n<t;++n)r[n]=e[n];return r}Object.defineProperty(s,"defaultMaxListeners",{enumerable:!0,get:function(){return a},set:function(e){if("number"!=typeof e||e<0||i(e))throw new RangeError('The value of "defaultMaxListeners" is out of range. It must be a non-negative number. Received '+e+".");a=e}}),s.init=function(){void 0!==this._events&&this._events!==Object.getPrototypeOf(this)._events||(this._events=Object.create(null),this._eventsCount=0),this._maxListeners=this._maxListeners||void 0},s.prototype.setMaxListeners=function(e){if("number"!=typeof e||e<0||i(e))throw new RangeError('The value of "n" is out of range. It must be a non-negative number. Received '+e+".");return this._maxListeners=e,this},s.prototype.getMaxListeners=function(){return u(this)},s.prototype.emit=function(e){for(var t=[],r=1;r<arguments.length;r++)t.push(arguments[r]);var n="error"===e,o=this._events;if(void 0!==o)n=n&&void 0===o.error;else if(!n)return!1;if(n){var i;if(0<t.length&&(i=t[0]),i instanceof Error)throw i;var s=new Error("Unhandled error."+(i?" ("+i.message+")":""));throw s.context=i,s}var a=o[e];if(void 0===a)return!1;if("function"==typeof a)l(a,this,t);else{var u=a.length,d=h(a,u);for(r=0;r<u;++r)l(d[r],this,t)}return!0},s.prototype.on=s.prototype.addListener=function(e,t){return d(this,e,t,!1)},s.prototype.prependListener=function(e,t){return d(this,e,t,!0)},s.prototype.once=function(e,t){if("function"!=typeof t)throw new TypeError('The "listener" argument must be of type Function. Received type '+typeof t);return this.on(e,f(this,e,t)),this},s.prototype.prependOnceListener=function(e,t){if("function"!=typeof t)throw new TypeError('The "listener" argument must be of type Function. Received type '+typeof t);return this.prependListener(e,f(this,e,t)),this},s.prototype.off=s.prototype.removeListener=function(e,t){var r,n,o,i,s;if("function"!=typeof t)throw new TypeError('The "listener" argument must be of type Function. Received type '+typeof t);if(void 0===(n=this._events))return this;if(void 0===(r=n[e]))return this;if(r===t||r.listener===t)0==--this._eventsCount?this._events=Object.create(null):(delete n[e],n.removeListener&&this.emit("removeListener",e,r.listener||t));else if("function"!=typeof r){for(o=-1,i=r.length-1;0<=i;i--)if(r[i]===t||r[i].listener===t){s=r[i].listener,o=i;break}if(o<0)return this;0===o?r.shift():function(e,t){for(;t+1<e.length;t++)e[t]=e[t+1];e.pop()}(r,o),1===r.length&&(n[e]=r[0]),void 0!==n.removeListener&&this.emit("removeListener",e,s||t)}return this},s.prototype.removeAllListeners=function(e){var t,r,n;if(void 0===(r=this._events))return this;if(void 0===r.removeListener)return 0===arguments.length?(this._events=Object.create(null),this._eventsCount=0):void 0!==r[e]&&(0==--this._eventsCount?this._events=Object.create(null):delete r[e]),this;if(0===arguments.length){var o,i=Object.keys(r);for(n=0;n<i.length;++n)"removeListener"!==(o=i[n])&&this.removeAllListeners(o);return this.removeAllListeners("removeListener"),this._events=Object.create(null),this._eventsCount=0,this}if("function"==typeof(t=r[e]))this.removeListener(e,t);else if(void 0!==t)for(n=t.length-1;0<=n;n--)this.removeListener(e,t[n]);return this},s.prototype.listeners=function(e){return c(this,e,!0)},s.prototype.rawListeners=function(e){return c(this,e,!1)},s.listenerCount=function(e,t){return"function"==typeof e.listenerCount?e.listenerCount(t):p.call(e,t)},s.prototype.listenerCount=p,s.prototype.eventNames=function(){return 0<this._eventsCount?n(this._events):[]}},"./node_modules/for-each/index.js":
/*!****************************************!*\
  !*** ./node_modules/for-each/index.js ***!
  \****************************************/
/*! no static exports found */function(e,t,r){"use strict";var o=r(/*! is-callable */"./node_modules/is-callable/index.js"),i=Object.prototype.toString,s=Object.prototype.hasOwnProperty;e.exports=function(e,t,r){if(!o(t))throw new TypeError("iterator must be a function");var n;3<=arguments.length&&(n=r),"[object Array]"===i.call(e)?function(e,t,r){for(var n=0,o=e.length;n<o;n++)s.call(e,n)&&(null==r?t(e[n],n,e):t.call(r,e[n],n,e))}(e,t,n):"string"==typeof e?function(e,t,r){for(var n=0,o=e.length;n<o;n++)null==r?t(e.charAt(n),n,e):t.call(r,e.charAt(n),n,e)}(e,t,n):function(e,t,r){for(var n in e)s.call(e,n)&&(null==r?t(e[n],n,e):t.call(r,e[n],n,e))}(e,t,n)}},"./node_modules/function-bind/implementation.js":
/*!******************************************************!*\
  !*** ./node_modules/function-bind/implementation.js ***!
  \******************************************************/
/*! no static exports found */function(e,t,r){"use strict";var u=Array.prototype.slice,d=Object.prototype.toString;e.exports=function(t){var r=this;if("function"!=typeof r||"[object Function]"!==d.call(r))throw new TypeError("Function.prototype.bind called on incompatible "+r);for(var n,o=u.call(arguments,1),e=Math.max(0,r.length-o.length),i=[],s=0;s<e;s++)i.push("$"+s);if(n=Function("binder","return function ("+i.join(",")+"){ return binder.apply(this,arguments); }")(function(){if(this instanceof n){var e=r.apply(this,o.concat(u.call(arguments)));return Object(e)===e?e:this}return r.apply(t,o.concat(u.call(arguments)))}),r.prototype){var a=function(){};a.prototype=r.prototype,n.prototype=new a,a.prototype=null}return n}},"./node_modules/function-bind/index.js":
/*!*********************************************!*\
  !*** ./node_modules/function-bind/index.js ***!
  \*********************************************/
/*! no static exports found */function(e,t,r){"use strict";var n=r(/*! ./implementation */"./node_modules/function-bind/implementation.js");e.exports=Function.prototype.bind||n},"./node_modules/has/src/index.js":
/*!***************************************!*\
  !*** ./node_modules/has/src/index.js ***!
  \***************************************/
/*! no static exports found */function(e,t,r){"use strict";var n=r(/*! function-bind */"./node_modules/function-bind/index.js");e.exports=n.call(Function.call,Object.prototype.hasOwnProperty)},"./node_modules/ieee754/index.js":
/*!***************************************!*\
  !*** ./node_modules/ieee754/index.js ***!
  \***************************************/
/*! no static exports found */function(e,t){t.read=function(e,t,r,n,o){var i,s,a=8*o-n-1,u=(1<<a)-1,d=u>>1,l=-7,f=r?o-1:0,c=r?-1:1,p=e[t+f];for(f+=c,i=p&(1<<-l)-1,p>>=-l,l+=a;0<l;i=256*i+e[t+f],f+=c,l-=8);for(s=i&(1<<-l)-1,i>>=-l,l+=n;0<l;s=256*s+e[t+f],f+=c,l-=8);if(0===i)i=1-d;else{if(i===u)return s?NaN:1/0*(p?-1:1);s+=Math.pow(2,n),i-=d}return(p?-1:1)*s*Math.pow(2,i-n)},t.write=function(e,t,r,n,o,i){var s,a,u,d=8*i-o-1,l=(1<<d)-1,f=l>>1,c=23===o?Math.pow(2,-24)-Math.pow(2,-77):0,p=n?0:i-1,h=n?1:-1,m=t<0||0===t&&1/t<0?1:0;for(t=Math.abs(t),isNaN(t)||t===1/0?(a=isNaN(t)?1:0,s=l):(s=Math.floor(Math.log(t)/Math.LN2),t*(u=Math.pow(2,-s))<1&&(s--,u*=2),2<=(t+=1<=s+f?c/u:c*Math.pow(2,1-f))*u&&(s++,u/=2),l<=s+f?(a=0,s=l):1<=s+f?(a=(t*u-1)*Math.pow(2,o),s+=f):(a=t*Math.pow(2,f-1)*Math.pow(2,o),s=0));8<=o;e[r+p]=255&a,p+=h,a/=256,o-=8);for(s=s<<o|a,d+=o;0<d;e[r+p]=255&s,p+=h,s/=256,d-=8);e[r+p-h]|=128*m}},"./node_modules/inherits/inherits_browser.js":
/*!***************************************************!*\
  !*** ./node_modules/inherits/inherits_browser.js ***!
  \***************************************************/
/*! no static exports found */function(e,t){"function"==typeof Object.create?e.exports=function(e,t){t&&(e.super_=t,e.prototype=Object.create(t.prototype,{constructor:{value:e,enumerable:!1,writable:!0,configurable:!0}}))}:e.exports=function(e,t){if(t){e.super_=t;function r(){}r.prototype=t.prototype,e.prototype=new r,e.prototype.constructor=e}}},"./node_modules/is-callable/index.js":
/*!*******************************************!*\
  !*** ./node_modules/is-callable/index.js ***!
  \*******************************************/
/*! no static exports found */function(e,t,r){"use strict";function n(e){try{var t=o.call(e);return i.test(t)}catch(e){return!1}}var o=Function.prototype.toString,i=/^\s*class\b/,s=Object.prototype.toString,a="function"==typeof Symbol&&"symbol"==typeof Symbol.toStringTag;e.exports=function(e){if(!e)return!1;if("function"!=typeof e&&"object"!=typeof e)return!1;if("function"==typeof e&&!e.prototype)return!0;if(a)return function(e){try{return!n(e)&&(o.call(e),!0)}catch(e){return!1}}(e);if(n(e))return!1;var t=s.call(e);return"[object Function]"===t||"[object GeneratorFunction]"===t}},"./node_modules/isarray/index.js":
/*!***************************************!*\
  !*** ./node_modules/isarray/index.js ***!
  \***************************************/
/*! no static exports found */function(e,t){var r={}.toString;e.exports=Array.isArray||function(e){return"[object Array]"==r.call(e)}},"./node_modules/node-libs-browser/mock/empty.js":
/*!******************************************************!*\
  !*** ./node_modules/node-libs-browser/mock/empty.js ***!
  \******************************************************/
/*! no static exports found */function(e,t){},"./node_modules/object-inspect/index.js":
/*!**********************************************!*\
  !*** ./node_modules/object-inspect/index.js ***!
  \**********************************************/
/*! no static exports found */function(e,t,r){var n="function"==typeof Map&&Map.prototype,o=Object.getOwnPropertyDescriptor&&n?Object.getOwnPropertyDescriptor(Map.prototype,"size"):null,m=n&&o&&"function"==typeof o.get?o.get:null,y=n&&Map.prototype.forEach,i="function"==typeof Set&&Set.prototype,s=Object.getOwnPropertyDescriptor&&i?Object.getOwnPropertyDescriptor(Set.prototype,"size"):null,b=i&&s&&"function"==typeof s.get?s.get:null,g=i&&Set.prototype.forEach,v=Boolean.prototype.valueOf,a=Object.prototype.toString,_="function"==typeof BigInt?BigInt.prototype.valueOf:null,u=r(/*! ./util.inspect */2).custom,w=u&&j(u)?u:null;function E(e,t,r){var n="double"===(r.quoteStyle||t)?'"':"'";return n+e+n}function x(e){return"[object Array]"===A(e)}function j(e){return"[object Symbol]"===A(e)}e.exports=function r(n,o,i,s){if(S(o=o||{},"quoteStyle")&&"single"!==o.quoteStyle&&"double"!==o.quoteStyle)throw new TypeError('option "quoteStyle" must be "single" or "double"');if(void 0===n)return"undefined";if(null===n)return"null";if("boolean"==typeof n)return n?"true":"false";if("string"==typeof n)return function(e,t){return E(e.replace(/(['\\])/g,"\\$1").replace(/[\x00-\x1f]/g,P),"single",t)}(n,o);if("number"==typeof n)return 0===n?0<1/0/n?"0":"-0":String(n);if("bigint"==typeof n)return String(n)+"n";var e,t=void 0===o.depth?5:o.depth;if(void 0===i&&(i=0),t<=i&&0<t&&"object"==typeof n)return"[Object]";if(void 0===s)s=[];else if(0<=function(e,t){if(e.indexOf)return e.indexOf(t);for(var r=0,n=e.length;r<n;r++)if(e[r]===t)return r;return-1}(s,n))return"[Circular]";function a(e,t){return t&&(s=s.slice()).push(t),r(e,o,i+1,s)}if("function"==typeof n){var u=function(e){if(e.name)return e.name;var t=String(e).match(/^function\s*([\w$]+)/);if(t)return t[1]}(n);return"[Function"+(u?": "+u:"")+"]"}if(j(n)){var d=Symbol.prototype.toString.call(n);return"object"==typeof n?T(d):d}if(function(e){if(!e||"object"!=typeof e)return!1;if("undefined"!=typeof HTMLElement&&e instanceof HTMLElement)return!0;return"string"==typeof e.nodeName&&"function"==typeof e.getAttribute}(n)){for(var l="<"+String(n.nodeName).toLowerCase(),f=n.attributes||[],c=0;c<f.length;c++)l+=" "+f[c].name+"="+E((e=f[c].value,String(e).replace(/"/g,"&quot;")),"double",o);return l+=">",n.childNodes&&n.childNodes.length&&(l+="..."),l+="</"+String(n.nodeName).toLowerCase()+">"}if(x(n))return 0===n.length?"[]":"[ "+k(n,a).join(", ")+" ]";if(function(e){return"[object Error]"===A(e)}(n))return 0===(p=k(n,a)).length?"["+String(n)+"]":"{ ["+String(n)+"] "+p.join(", ")+" }";if("object"==typeof n){if(w&&"function"==typeof n[w])return n[w]();if("function"==typeof n.inspect)return n.inspect()}if(function(e){if(!m)return!1;try{m.call(e);try{b.call(e)}catch(e){return!0}return e instanceof Map}catch(e){}return!1}(n)){var p=[];return y.call(n,function(e,t){p.push(a(t,n)+" => "+a(e,n))}),O("Map",m.call(n),p)}if(function(e){if(!b)return!1;try{b.call(e);try{m.call(e)}catch(e){return!0}return e instanceof Set}catch(e){}return!1}(n)){p=[];return g.call(n,function(e){p.push(a(e,n))}),O("Set",b.call(n),p)}if(function(e){return"[object Number]"===A(e)}(n))return T(a(Number(n)));if(function(e){return"[object BigInt]"===A(e)}(n))return T(a(_.call(n)));if(function(e){return"[object Boolean]"===A(e)}(n))return T(v.call(n));if(function(e){return"[object String]"===A(e)}(n))return T(a(String(n)));if(function(e){return"[object Date]"===A(e)}(n)||function(e){return"[object RegExp]"===A(e)}(n))return String(n);var h=k(n,a);return 0===h.length?"{}":"{ "+h.join(", ")+" }"};var d=Object.prototype.hasOwnProperty||function(e){return e in this};function S(e,t){return d.call(e,t)}function A(e){return a.call(e)}function P(e){var t=e.charCodeAt(0),r={8:"b",9:"t",10:"n",12:"f",13:"r"}[t];return r?"\\"+r:"\\x"+(t<16?"0":"")+t.toString(16)}function T(e){return"Object("+e+")"}function O(e,t,r){return e+" ("+t+") {"+r.join(", ")+"}"}function k(e,t){var r=x(e),n=[];if(r){n.length=e.length;for(var o=0;o<e.length;o++)n[o]=S(e,o)?t(e[o],e):""}for(var i in e)S(e,i)&&(r&&String(Number(i))===i&&i<e.length||(/[^\w$]/.test(i)?n.push(t(i,e)+": "+t(e[i],e)):n.push(i+": "+t(e[i],e))));return n}},"./node_modules/object-keys/implementation.js":
/*!****************************************************!*\
  !*** ./node_modules/object-keys/implementation.js ***!
  \****************************************************/
/*! no static exports found */function(e,t,r){"use strict";var n;if(!Object.keys){var c=Object.prototype.hasOwnProperty,p=Object.prototype.toString,h=r(/*! ./isArguments */"./node_modules/object-keys/isArguments.js"),o=Object.prototype.propertyIsEnumerable,m=!o.call({toString:null},"toString"),y=o.call(function(){},"prototype"),b=["toString","toLocaleString","valueOf","hasOwnProperty","isPrototypeOf","propertyIsEnumerable","constructor"],g=function(e){var t=e.constructor;return t&&t.prototype===e},i={$applicationCache:!0,$console:!0,$external:!0,$frame:!0,$frameElement:!0,$frames:!0,$innerHeight:!0,$innerWidth:!0,$onmozfullscreenchange:!0,$onmozfullscreenerror:!0,$outerHeight:!0,$outerWidth:!0,$pageXOffset:!0,$pageYOffset:!0,$parent:!0,$scrollLeft:!0,$scrollTop:!0,$scrollX:!0,$scrollY:!0,$self:!0,$webkitIndexedDB:!0,$webkitStorageInfo:!0,$window:!0},v=function(){if("undefined"==typeof window)return!1;for(var e in window)try{if(!i["$"+e]&&c.call(window,e)&&null!==window[e]&&"object"==typeof window[e])try{g(window[e])}catch(e){return!0}}catch(e){return!0}return!1}();n=function(e){var t=null!==e&&"object"==typeof e,r="[object Function]"===p.call(e),n=h(e),o=t&&"[object String]"===p.call(e),i=[];if(!t&&!r&&!n)throw new TypeError("Object.keys called on a non-object");var s=y&&r;if(o&&0<e.length&&!c.call(e,0))for(var a=0;a<e.length;++a)i.push(String(a));if(n&&0<e.length)for(var u=0;u<e.length;++u)i.push(String(u));else for(var d in e)s&&"prototype"===d||!c.call(e,d)||i.push(String(d));if(m)for(var l=function(e){if("undefined"==typeof window||!v)return g(e);try{return g(e)}catch(e){return!1}}(e),f=0;f<b.length;++f)l&&"constructor"===b[f]||!c.call(e,b[f])||i.push(b[f]);return i}}e.exports=n},"./node_modules/object-keys/index.js":
/*!*******************************************!*\
  !*** ./node_modules/object-keys/index.js ***!
  \*******************************************/
/*! no static exports found */function(e,t,r){"use strict";var n=Array.prototype.slice,o=r(/*! ./isArguments */"./node_modules/object-keys/isArguments.js"),i=Object.keys,s=i?function(e){return i(e)}:r(/*! ./implementation */"./node_modules/object-keys/implementation.js"),a=Object.keys;s.shim=function(){Object.keys?function(){var e=Object.keys(arguments);return e&&e.length===arguments.length}(1,2)||(Object.keys=function(e){return o(e)?a(n.call(e)):a(e)}):Object.keys=s;return Object.keys||s},e.exports=s},"./node_modules/object-keys/isArguments.js":
/*!*************************************************!*\
  !*** ./node_modules/object-keys/isArguments.js ***!
  \*************************************************/
/*! no static exports found */function(e,t,r){"use strict";var n=Object.prototype.toString;e.exports=function(e){var t=n.call(e),r="[object Arguments]"===t;return r=r||"[object Array]"!==t&&null!==e&&"object"==typeof e&&"number"==typeof e.length&&0<=e.length&&"[object Function]"===n.call(e.callee)}},"./node_modules/path-browserify/index.js":
/*!***********************************************!*\
  !*** ./node_modules/path-browserify/index.js ***!
  \***********************************************/
/*! no static exports found */function(e,d,t){(function(o){function i(e,t){for(var r=0,n=e.length-1;0<=n;n--){var o=e[n];"."===o?e.splice(n,1):".."===o?(e.splice(n,1),r++):r&&(e.splice(n,1),r--)}if(t)for(;r--;)e.unshift("..");return e}function s(e,t){if(e.filter)return e.filter(t);for(var r=[],n=0;n<e.length;n++)t(e[n],n,e)&&r.push(e[n]);return r}d.resolve=function(){for(var e="",t=!1,r=arguments.length-1;-1<=r&&!t;r--){var n=0<=r?arguments[r]:o.cwd();if("string"!=typeof n)throw new TypeError("Arguments to path.resolve must be strings");n&&(e=n+"/"+e,t="/"===n.charAt(0))}return(t?"/":"")+(e=i(s(e.split("/"),function(e){return!!e}),!t).join("/"))||"."},d.normalize=function(e){var t=d.isAbsolute(e),r="/"===n(e,-1);return(e=i(s(e.split("/"),function(e){return!!e}),!t).join("/"))||t||(e="."),e&&r&&(e+="/"),(t?"/":"")+e},d.isAbsolute=function(e){return"/"===e.charAt(0)},d.join=function(){var e=Array.prototype.slice.call(arguments,0);return d.normalize(s(e,function(e,t){if("string"!=typeof e)throw new TypeError("Arguments to path.join must be strings");return e}).join("/"))},d.relative=function(e,t){function r(e){for(var t=0;t<e.length&&""===e[t];t++);for(var r=e.length-1;0<=r&&""===e[r];r--);return r<t?[]:e.slice(t,r-t+1)}e=d.resolve(e).substr(1),t=d.resolve(t).substr(1);for(var n=r(e.split("/")),o=r(t.split("/")),i=Math.min(n.length,o.length),s=i,a=0;a<i;a++)if(n[a]!==o[a]){s=a;break}var u=[];for(a=s;a<n.length;a++)u.push("..");return(u=u.concat(o.slice(s))).join("/")},d.sep="/",d.delimiter=":",d.dirname=function(e){if("string"!=typeof e&&(e+=""),0===e.length)return".";for(var t=e.charCodeAt(0),r=47===t,n=-1,o=!0,i=e.length-1;1<=i;--i)if(47===(t=e.charCodeAt(i))){if(!o){n=i;break}}else o=!1;return-1===n?r?"/":".":r&&1===n?"/":e.slice(0,n)},d.basename=function(e,t){var r=function(e){"string"!=typeof e&&(e+="");var t,r=0,n=-1,o=!0;for(t=e.length-1;0<=t;--t)if(47===e.charCodeAt(t)){if(!o){r=t+1;break}}else-1===n&&(o=!1,n=t+1);return-1===n?"":e.slice(r,n)}(e);return t&&r.substr(-1*t.length)===t&&(r=r.substr(0,r.length-t.length)),r},d.extname=function(e){"string"!=typeof e&&(e+="");for(var t=-1,r=0,n=-1,o=!0,i=0,s=e.length-1;0<=s;--s){var a=e.charCodeAt(s);if(47===a){if(o)continue;r=s+1;break}-1===n&&(o=!1,n=s+1),46===a?-1===t?t=s:1!==i&&(i=1):-1!==t&&(i=-1)}return-1===t||-1===n||0===i||1===i&&t===n-1&&t===r+1?"":e.slice(t,n)};var n="b"==="ab".substr(-1)?function(e,t,r){return e.substr(t,r)}:function(e,t,r){return t<0&&(t=e.length+t),e.substr(t,r)}}).call(this,t(/*! ./../process/browser.js */"./node_modules/process/browser.js"))},"./node_modules/process-nextick-args/index.js":
/*!****************************************************!*\
  !*** ./node_modules/process-nextick-args/index.js ***!
  \****************************************************/
/*! no static exports found */function(e,t,r){"use strict";(function(a){void 0===a||!a.version||0===a.version.indexOf("v0.")||0===a.version.indexOf("v1.")&&0!==a.version.indexOf("v1.8.")?e.exports={nextTick:function(e,t,r,n){if("function"!=typeof e)throw new TypeError('"callback" argument must be a function');var o,i,s=arguments.length;switch(s){case 0:case 1:return a.nextTick(e);case 2:return a.nextTick(function(){e.call(null,t)});case 3:return a.nextTick(function(){e.call(null,t,r)});case 4:return a.nextTick(function(){e.call(null,t,r,n)});default:for(o=new Array(s-1),i=0;i<o.length;)o[i++]=arguments[i];return a.nextTick(function(){e.apply(null,o)})}}}:e.exports=a}).call(this,r(/*! ./../process/browser.js */"./node_modules/process/browser.js"))},"./node_modules/process/browser.js":
/*!*****************************************!*\
  !*** ./node_modules/process/browser.js ***!
  \*****************************************/
/*! no static exports found */function(e,t){var r,n,o=e.exports={};function i(){throw new Error("setTimeout has not been defined")}function s(){throw new Error("clearTimeout has not been defined")}function a(t){if(r===setTimeout)return setTimeout(t,0);if((r===i||!r)&&setTimeout)return r=setTimeout,setTimeout(t,0);try{return r(t,0)}catch(e){try{return r.call(null,t,0)}catch(e){return r.call(this,t,0)}}}!function(){try{r="function"==typeof setTimeout?setTimeout:i}catch(e){r=i}try{n="function"==typeof clearTimeout?clearTimeout:s}catch(e){n=s}}();var u,d=[],l=!1,f=-1;function c(){l&&u&&(l=!1,u.length?d=u.concat(d):f=-1,d.length&&p())}function p(){if(!l){var e=a(c);l=!0;for(var t=d.length;t;){for(u=d,d=[];++f<t;)u&&u[f].run();f=-1,t=d.length}u=null,l=!1,function(t){if(n===clearTimeout)return clearTimeout(t);if((n===s||!n)&&clearTimeout)return n=clearTimeout,clearTimeout(t);try{n(t)}catch(e){try{return n.call(null,t)}catch(e){return n.call(this,t)}}}(e)}}function h(e,t){this.fun=e,this.array=t}function m(){}o.nextTick=function(e){var t=new Array(arguments.length-1);if(1<arguments.length)for(var r=1;r<arguments.length;r++)t[r-1]=arguments[r];d.push(new h(e,t)),1!==d.length||l||a(p)},h.prototype.run=function(){this.fun.apply(null,this.array)},o.title="browser",o.browser=!0,o.env={},o.argv=[],o.version="",o.versions={},o.on=m,o.addListener=m,o.once=m,o.off=m,o.removeListener=m,o.removeAllListeners=m,o.emit=m,o.prependListener=m,o.prependOnceListener=m,o.listeners=function(e){return[]},o.binding=function(e){throw new Error("process.binding is not supported")},o.cwd=function(){return"/"},o.chdir=function(e){throw new Error("process.chdir is not supported")},o.umask=function(){return 0}},"./node_modules/readable-stream/duplex-browser.js":
/*!********************************************************!*\
  !*** ./node_modules/readable-stream/duplex-browser.js ***!
  \********************************************************/
/*! no static exports found */function(e,t,r){e.exports=r(/*! ./lib/_stream_duplex.js */"./node_modules/readable-stream/lib/_stream_duplex.js")},"./node_modules/readable-stream/lib/_stream_duplex.js":
/*!************************************************************!*\
  !*** ./node_modules/readable-stream/lib/_stream_duplex.js ***!
  \************************************************************/
/*! no static exports found */function(e,t,r){"use strict";var n=r(/*! process-nextick-args */"./node_modules/process-nextick-args/index.js"),o=Object.keys||function(e){var t=[];for(var r in e)t.push(r);return t};e.exports=f;var i=r(/*! core-util-is */"./node_modules/core-util-is/lib/util.js");i.inherits=r(/*! inherits */"./node_modules/inherits/inherits_browser.js");var s=r(/*! ./_stream_readable */"./node_modules/readable-stream/lib/_stream_readable.js"),a=r(/*! ./_stream_writable */"./node_modules/readable-stream/lib/_stream_writable.js");i.inherits(f,s);for(var u=o(a.prototype),d=0;d<u.length;d++){var l=u[d];f.prototype[l]||(f.prototype[l]=a.prototype[l])}function f(e){if(!(this instanceof f))return new f(e);s.call(this,e),a.call(this,e),e&&!1===e.readable&&(this.readable=!1),e&&!1===e.writable&&(this.writable=!1),this.allowHalfOpen=!0,e&&!1===e.allowHalfOpen&&(this.allowHalfOpen=!1),this.once("end",c)}function c(){this.allowHalfOpen||this._writableState.ended||n.nextTick(p,this)}function p(e){e.end()}Object.defineProperty(f.prototype,"writableHighWaterMark",{enumerable:!1,get:function(){return this._writableState.highWaterMark}}),Object.defineProperty(f.prototype,"destroyed",{get:function(){return void 0!==this._readableState&&void 0!==this._writableState&&(this._readableState.destroyed&&this._writableState.destroyed)},set:function(e){void 0!==this._readableState&&void 0!==this._writableState&&(this._readableState.destroyed=e,this._writableState.destroyed=e)}}),f.prototype._destroy=function(e,t){this.push(null),this.end(),n.nextTick(t,e)}},"./node_modules/readable-stream/lib/_stream_passthrough.js":
/*!*****************************************************************!*\
  !*** ./node_modules/readable-stream/lib/_stream_passthrough.js ***!
  \*****************************************************************/
/*! no static exports found */function(e,t,r){"use strict";e.exports=i;var n=r(/*! ./_stream_transform */"./node_modules/readable-stream/lib/_stream_transform.js"),o=r(/*! core-util-is */"./node_modules/core-util-is/lib/util.js");function i(e){if(!(this instanceof i))return new i(e);n.call(this,e)}o.inherits=r(/*! inherits */"./node_modules/inherits/inherits_browser.js"),o.inherits(i,n),i.prototype._transform=function(e,t,r){r(null,e)}},"./node_modules/readable-stream/lib/_stream_readable.js":
/*!**************************************************************!*\
  !*** ./node_modules/readable-stream/lib/_stream_readable.js ***!
  \**************************************************************/
/*! no static exports found */function(D,e,B){"use strict";(function(e,m){var y=B(/*! process-nextick-args */"./node_modules/process-nextick-args/index.js");D.exports=c;var s,b=B(/*! isarray */"./node_modules/isarray/index.js");c.ReadableState=i;function g(e,t){return e.listeners(t).length}B(/*! events */"./node_modules/events/events.js").EventEmitter;var o=B(/*! ./internal/streams/stream */"./node_modules/readable-stream/lib/internal/streams/stream-browser.js"),a=B(/*! safe-buffer */"./node_modules/readable-stream/node_modules/safe-buffer/index.js").Buffer,u=e.Uint8Array||function(){};var t=B(/*! core-util-is */"./node_modules/core-util-is/lib/util.js");t.inherits=B(/*! inherits */"./node_modules/inherits/inherits_browser.js");var r=B(/*! util */0),v=void 0;v=r&&r.debuglog?r.debuglog("stream"):function(){};var d,l=B(/*! ./internal/streams/BufferList */"./node_modules/readable-stream/lib/internal/streams/BufferList.js"),n=B(/*! ./internal/streams/destroy */"./node_modules/readable-stream/lib/internal/streams/destroy.js");t.inherits(c,o);var f=["error","close","destroy","pause","resume"];function i(e,t){e=e||{};var r=t instanceof(s=s||B(/*! ./_stream_duplex */"./node_modules/readable-stream/lib/_stream_duplex.js"));this.objectMode=!!e.objectMode,r&&(this.objectMode=this.objectMode||!!e.readableObjectMode);var n=e.highWaterMark,o=e.readableHighWaterMark,i=this.objectMode?16:16384;this.highWaterMark=n||0===n?n:r&&(o||0===o)?o:i,this.highWaterMark=Math.floor(this.highWaterMark),this.buffer=new l,this.length=0,this.pipes=null,this.pipesCount=0,this.flowing=null,this.ended=!1,this.endEmitted=!1,this.reading=!1,this.sync=!0,this.needReadable=!1,this.emittedReadable=!1,this.readableListening=!1,this.resumeScheduled=!1,this.destroyed=!1,this.defaultEncoding=e.defaultEncoding||"utf8",this.awaitDrain=0,this.readingMore=!1,this.decoder=null,this.encoding=null,e.encoding&&(d=d||B(/*! string_decoder/ */"./node_modules/string_decoder/lib/string_decoder.js").StringDecoder,this.decoder=new d(e.encoding),this.encoding=e.encoding)}function c(e){if(s=s||B(/*! ./_stream_duplex */"./node_modules/readable-stream/lib/_stream_duplex.js"),!(this instanceof c))return new c(e);this._readableState=new i(e,this),this.readable=!0,e&&("function"==typeof e.read&&(this._read=e.read),"function"==typeof e.destroy&&(this._destroy=e.destroy)),o.call(this)}function p(e,t,r,n,o){var i,s=e._readableState;null===t?(s.reading=!1,function(e,t){if(t.ended)return;if(t.decoder){var r=t.decoder.end();r&&r.length&&(t.buffer.push(r),t.length+=t.objectMode?1:r.length)}t.ended=!0,E(e)}(e,s)):(o||(i=function(e,t){var r;(function(e){return a.isBuffer(e)||e instanceof u})(t)||"string"==typeof t||void 0===t||e.objectMode||(r=new TypeError("Invalid non-string/buffer chunk"));return r}(s,t)),i?e.emit("error",i):s.objectMode||t&&0<t.length?("string"==typeof t||s.objectMode||Object.getPrototypeOf(t)===a.prototype||(t=function(e){return a.from(e)}(t)),n?s.endEmitted?e.emit("error",new Error("stream.unshift() after end event")):h(e,s,t,!0):s.ended?e.emit("error",new Error("stream.push() after EOF")):(s.reading=!1,s.decoder&&!r?(t=s.decoder.write(t),s.objectMode||0!==t.length?h(e,s,t,!1):j(e,s)):h(e,s,t,!1))):n||(s.reading=!1));return function(e){return!e.ended&&(e.needReadable||e.length<e.highWaterMark||0===e.length)}(s)}function h(e,t,r,n){t.flowing&&0===t.length&&!t.sync?(e.emit("data",r),e.read(0)):(t.length+=t.objectMode?1:r.length,n?t.buffer.unshift(r):t.buffer.push(r),t.needReadable&&E(e)),j(e,t)}Object.defineProperty(c.prototype,"destroyed",{get:function(){return void 0!==this._readableState&&this._readableState.destroyed},set:function(e){this._readableState&&(this._readableState.destroyed=e)}}),c.prototype.destroy=n.destroy,c.prototype._undestroy=n.undestroy,c.prototype._destroy=function(e,t){this.push(null),t(e)},c.prototype.push=function(e,t){var r,n=this._readableState;return n.objectMode?r=!0:"string"==typeof e&&((t=t||n.defaultEncoding)!==n.encoding&&(e=a.from(e,t),t=""),r=!0),p(this,e,t,!1,r)},c.prototype.unshift=function(e){return p(this,e,null,!0,!1)},c.prototype.isPaused=function(){return!1===this._readableState.flowing},c.prototype.setEncoding=function(e){return d=d||B(/*! string_decoder/ */"./node_modules/string_decoder/lib/string_decoder.js").StringDecoder,this._readableState.decoder=new d(e),this._readableState.encoding=e,this};var _=8388608;function w(e,t){return e<=0||0===t.length&&t.ended?0:t.objectMode?1:e!=e?t.flowing&&t.length?t.buffer.head.data.length:t.length:(e>t.highWaterMark&&(t.highWaterMark=function(e){return _<=e?e=_:(e--,e|=e>>>1,e|=e>>>2,e|=e>>>4,e|=e>>>8,e|=e>>>16,e++),e}(e)),e<=t.length?e:t.ended?t.length:(t.needReadable=!0,0))}function E(e){var t=e._readableState;t.needReadable=!1,t.emittedReadable||(v("emitReadable",t.flowing),t.emittedReadable=!0,t.sync?y.nextTick(x,e):x(e))}function x(e){v("emit readable"),e.emit("readable"),T(e)}function j(e,t){t.readingMore||(t.readingMore=!0,y.nextTick(S,e,t))}function S(e,t){for(var r=t.length;!t.reading&&!t.flowing&&!t.ended&&t.length<t.highWaterMark&&(v("maybeReadMore read 0"),e.read(0),r!==t.length);)r=t.length;t.readingMore=!1}function A(e){v("readable nexttick read 0"),e.read(0)}function P(e,t){t.reading||(v("resume read 0"),e.read(0)),t.resumeScheduled=!1,t.awaitDrain=0,e.emit("resume"),T(e),t.flowing&&!t.reading&&e.read(0)}function T(e){var t=e._readableState;for(v("flow",t.flowing);t.flowing&&null!==e.read(););}function O(e,t){return 0===t.length?null:(t.objectMode?r=t.buffer.shift():!e||e>=t.length?(r=t.decoder?t.buffer.join(""):1===t.buffer.length?t.buffer.head.data:t.buffer.concat(t.length),t.buffer.clear()):r=function(e,t,r){var n;e<t.head.data.length?(n=t.head.data.slice(0,e),t.head.data=t.head.data.slice(e)):n=e===t.head.data.length?t.shift():r?function(e,t){var r=t.head,n=1,o=r.data;e-=o.length;for(;r=r.next;){var i=r.data,s=e>i.length?i.length:e;if(s===i.length?o+=i:o+=i.slice(0,e),0===(e-=s)){s===i.length?(++n,r.next?t.head=r.next:t.head=t.tail=null):(t.head=r).data=i.slice(s);break}++n}return t.length-=n,o}(e,t):function(e,t){var r=a.allocUnsafe(e),n=t.head,o=1;n.data.copy(r),e-=n.data.length;for(;n=n.next;){var i=n.data,s=e>i.length?i.length:e;if(i.copy(r,r.length-e,0,s),0===(e-=s)){s===i.length?(++o,n.next?t.head=n.next:t.head=t.tail=null):(t.head=n).data=i.slice(s);break}++o}return t.length-=o,r}(e,t);return n}(e,t.buffer,t.decoder),r);var r}function k(e){var t=e._readableState;if(0<t.length)throw new Error('"endReadable()" called on non-empty stream');t.endEmitted||(t.ended=!0,y.nextTick(N,t,e))}function N(e,t){e.endEmitted||0!==e.length||(e.endEmitted=!0,t.readable=!1,t.emit("end"))}function R(e,t){for(var r=0,n=e.length;r<n;r++)if(e[r]===t)return r;return-1}c.prototype.read=function(e){v("read",e),e=parseInt(e,10);var t=this._readableState,r=e;if(0!==e&&(t.emittedReadable=!1),0===e&&t.needReadable&&(t.length>=t.highWaterMark||t.ended))return v("read: emitReadable",t.length,t.ended),0===t.length&&t.ended?k(this):E(this),null;if(0===(e=w(e,t))&&t.ended)return 0===t.length&&k(this),null;var n,o=t.needReadable;return v("need readable",o),(0===t.length||t.length-e<t.highWaterMark)&&v("length less than watermark",o=!0),t.ended||t.reading?v("reading or ended",o=!1):o&&(v("do read"),t.reading=!0,t.sync=!0,0===t.length&&(t.needReadable=!0),this._read(t.highWaterMark),t.sync=!1,t.reading||(e=w(r,t))),null===(n=0<e?O(e,t):null)?(t.needReadable=!0,e=0):t.length-=e,0===t.length&&(t.ended||(t.needReadable=!0),r!==e&&t.ended&&k(this)),null!==n&&this.emit("data",n),n},c.prototype._read=function(e){this.emit("error",new Error("_read() is not implemented"))},c.prototype.pipe=function(r,e){var n=this,o=this._readableState;switch(o.pipesCount){case 0:o.pipes=r;break;case 1:o.pipes=[o.pipes,r];break;default:o.pipes.push(r)}o.pipesCount+=1,v("pipe count=%d opts=%j",o.pipesCount,e);var t=(!e||!1!==e.end)&&r!==m.stdout&&r!==m.stderr?s:h;function i(e,t){v("onunpipe"),e===n&&t&&!1===t.hasUnpiped&&(t.hasUnpiped=!0,v("cleanup"),r.removeListener("close",c),r.removeListener("finish",p),r.removeListener("drain",a),r.removeListener("error",f),r.removeListener("unpipe",i),n.removeListener("end",s),n.removeListener("end",h),n.removeListener("data",l),u=!0,!o.awaitDrain||r._writableState&&!r._writableState.needDrain||a())}function s(){v("onend"),r.end()}o.endEmitted?y.nextTick(t):n.once("end",t),r.on("unpipe",i);var a=function(t){return function(){var e=t._readableState;v("pipeOnDrain",e.awaitDrain),e.awaitDrain&&e.awaitDrain--,0===e.awaitDrain&&g(t,"data")&&(e.flowing=!0,T(t))}}(n);r.on("drain",a);var u=!1;var d=!1;function l(e){v("ondata"),(d=!1)!==r.write(e)||d||((1===o.pipesCount&&o.pipes===r||1<o.pipesCount&&-1!==R(o.pipes,r))&&!u&&(v("false write response, pause",n._readableState.awaitDrain),n._readableState.awaitDrain++,d=!0),n.pause())}function f(e){v("onerror",e),h(),r.removeListener("error",f),0===g(r,"error")&&r.emit("error",e)}function c(){r.removeListener("finish",p),h()}function p(){v("onfinish"),r.removeListener("close",c),h()}function h(){v("unpipe"),n.unpipe(r)}return n.on("data",l),function(e,t,r){if("function"==typeof e.prependListener)return e.prependListener(t,r);e._events&&e._events[t]?b(e._events[t])?e._events[t].unshift(r):e._events[t]=[r,e._events[t]]:e.on(t,r)}(r,"error",f),r.once("close",c),r.once("finish",p),r.emit("pipe",n),o.flowing||(v("pipe resume"),n.resume()),r},c.prototype.unpipe=function(e){var t=this._readableState,r={hasUnpiped:!1};if(0===t.pipesCount)return this;if(1===t.pipesCount)return e&&e!==t.pipes||(e=e||t.pipes,t.pipes=null,t.pipesCount=0,t.flowing=!1,e&&e.emit("unpipe",this,r)),this;if(!e){var n=t.pipes,o=t.pipesCount;t.pipes=null,t.pipesCount=0,t.flowing=!1;for(var i=0;i<o;i++)n[i].emit("unpipe",this,r);return this}var s=R(t.pipes,e);return-1===s||(t.pipes.splice(s,1),t.pipesCount-=1,1===t.pipesCount&&(t.pipes=t.pipes[0]),e.emit("unpipe",this,r)),this},c.prototype.addListener=c.prototype.on=function(e,t){var r=o.prototype.on.call(this,e,t);if("data"===e)!1!==this._readableState.flowing&&this.resume();else if("readable"===e){var n=this._readableState;n.endEmitted||n.readableListening||(n.readableListening=n.needReadable=!0,n.emittedReadable=!1,n.reading?n.length&&E(this):y.nextTick(A,this))}return r},c.prototype.resume=function(){var e=this._readableState;return e.flowing||(v("resume"),e.flowing=!0,function(e,t){t.resumeScheduled||(t.resumeScheduled=!0,y.nextTick(P,e,t))}(this,e)),this},c.prototype.pause=function(){return v("call pause flowing=%j",this._readableState.flowing),!1!==this._readableState.flowing&&(v("pause"),this._readableState.flowing=!1,this.emit("pause")),this},c.prototype.wrap=function(t){var r=this,n=this._readableState,o=!1;for(var e in t.on("end",function(){if(v("wrapped end"),n.decoder&&!n.ended){var e=n.decoder.end();e&&e.length&&r.push(e)}r.push(null)}),t.on("data",function(e){v("wrapped data"),n.decoder&&(e=n.decoder.write(e)),n.objectMode&&null==e||(n.objectMode||e&&e.length)&&(r.push(e)||(o=!0,t.pause()))}),t)void 0===this[e]&&"function"==typeof t[e]&&(this[e]=function(e){return function(){return t[e].apply(t,arguments)}}(e));for(var i=0;i<f.length;i++)t.on(f[i],this.emit.bind(this,f[i]));return this._read=function(e){v("wrapped _read",e),o&&(o=!1,t.resume())},this},Object.defineProperty(c.prototype,"readableHighWaterMark",{enumerable:!1,get:function(){return this._readableState.highWaterMark}}),c._fromList=O}).call(this,B(/*! ./../../webpack/buildin/global.js */"./node_modules/webpack/buildin/global.js"),B(/*! ./../../process/browser.js */"./node_modules/process/browser.js"))},"./node_modules/readable-stream/lib/_stream_transform.js":
/*!***************************************************************!*\
  !*** ./node_modules/readable-stream/lib/_stream_transform.js ***!
  \***************************************************************/
/*! no static exports found */function(e,t,r){"use strict";e.exports=i;var n=r(/*! ./_stream_duplex */"./node_modules/readable-stream/lib/_stream_duplex.js"),o=r(/*! core-util-is */"./node_modules/core-util-is/lib/util.js");function i(e){if(!(this instanceof i))return new i(e);n.call(this,e),this._transformState={afterTransform:function(e,t){var r=this._transformState;r.transforming=!1;var n=r.writecb;if(!n)return this.emit("error",new Error("write callback called multiple times"));r.writechunk=null,(r.writecb=null)!=t&&this.push(t),n(e);var o=this._readableState;o.reading=!1,(o.needReadable||o.length<o.highWaterMark)&&this._read(o.highWaterMark)}.bind(this),needTransform:!1,transforming:!1,writecb:null,writechunk:null,writeencoding:null},this._readableState.needReadable=!0,this._readableState.sync=!1,e&&("function"==typeof e.transform&&(this._transform=e.transform),"function"==typeof e.flush&&(this._flush=e.flush)),this.on("prefinish",s)}function s(){var r=this;"function"==typeof this._flush?this._flush(function(e,t){a(r,e,t)}):a(this,null,null)}function a(e,t,r){if(t)return e.emit("error",t);if(null!=r&&e.push(r),e._writableState.length)throw new Error("Calling transform done when ws.length != 0");if(e._transformState.transforming)throw new Error("Calling transform done when still transforming");return e.push(null)}o.inherits=r(/*! inherits */"./node_modules/inherits/inherits_browser.js"),o.inherits(i,n),i.prototype.push=function(e,t){return this._transformState.needTransform=!1,n.prototype.push.call(this,e,t)},i.prototype._transform=function(e,t,r){throw new Error("_transform() is not implemented")},i.prototype._write=function(e,t,r){var n=this._transformState;if(n.writecb=r,n.writechunk=e,n.writeencoding=t,!n.transforming){var o=this._readableState;(n.needTransform||o.needReadable||o.length<o.highWaterMark)&&this._read(o.highWaterMark)}},i.prototype._read=function(e){var t=this._transformState;null!==t.writechunk&&t.writecb&&!t.transforming?(t.transforming=!0,this._transform(t.writechunk,t.writeencoding,t.afterTransform)):t.needTransform=!0},i.prototype._destroy=function(e,t){var r=this;n.prototype._destroy.call(this,e,function(e){t(e),r.emit("close")})}},"./node_modules/readable-stream/lib/_stream_writable.js":
/*!**************************************************************!*\
  !*** ./node_modules/readable-stream/lib/_stream_writable.js ***!
  \**************************************************************/
/*! no static exports found */function(x,e,j){"use strict";(function(e,t,r){var a=j(/*! process-nextick-args */"./node_modules/process-nextick-args/index.js");function f(e){var t=this;this.next=null,this.entry=null,this.finish=function(){!function(e,t,r){var n=e.entry;e.entry=null;for(;n;){var o=n.callback;t.pendingcb--,o(r),n=n.next}t.corkedRequestsFree?t.corkedRequestsFree.next=e:t.corkedRequestsFree=e}(t,e)}}x.exports=y;var u,d=!e.browser&&-1<["v0.10","v0.9."].indexOf(e.version.slice(0,5))?t:a.nextTick;y.WritableState=m;var n=j(/*! core-util-is */"./node_modules/core-util-is/lib/util.js");n.inherits=j(/*! inherits */"./node_modules/inherits/inherits_browser.js");var o={deprecate:j(/*! util-deprecate */"./node_modules/util-deprecate/browser.js")},i=j(/*! ./internal/streams/stream */"./node_modules/readable-stream/lib/internal/streams/stream-browser.js"),l=j(/*! safe-buffer */"./node_modules/readable-stream/node_modules/safe-buffer/index.js").Buffer,s=r.Uint8Array||function(){};var c,p=j(/*! ./internal/streams/destroy */"./node_modules/readable-stream/lib/internal/streams/destroy.js");function h(){}function m(e,t){u=u||j(/*! ./_stream_duplex */"./node_modules/readable-stream/lib/_stream_duplex.js"),e=e||{};var r=t instanceof u;this.objectMode=!!e.objectMode,r&&(this.objectMode=this.objectMode||!!e.writableObjectMode);var n=e.highWaterMark,o=e.writableHighWaterMark,i=this.objectMode?16:16384;this.highWaterMark=n||0===n?n:r&&(o||0===o)?o:i,this.highWaterMark=Math.floor(this.highWaterMark),this.finalCalled=!1,this.needDrain=!1,this.ending=!1,this.ended=!1,this.finished=!1;var s=(this.destroyed=!1)===e.decodeStrings;this.decodeStrings=!s,this.defaultEncoding=e.defaultEncoding||"utf8",this.length=0,this.writing=!1,this.corked=0,this.sync=!0,this.bufferProcessing=!1,this.onwrite=function(e){!function(e,t){var r=e._writableState,n=r.sync,o=r.writecb;if(function(e){e.writing=!1,e.writecb=null,e.length-=e.writelen,e.writelen=0}(r),t)!function(e,t,r,n,o){--t.pendingcb,r?(a.nextTick(o,n),a.nextTick(E,e,t),e._writableState.errorEmitted=!0,e.emit("error",n)):(o(n),e._writableState.errorEmitted=!0,e.emit("error",n),E(e,t))}(e,r,n,t,o);else{var i=_(r);i||r.corked||r.bufferProcessing||!r.bufferedRequest||v(e,r),n?d(g,e,r,i,o):g(e,r,i,o)}}(t,e)},this.writecb=null,this.writelen=0,this.bufferedRequest=null,this.lastBufferedRequest=null,this.pendingcb=0,this.prefinished=!1,this.errorEmitted=!1,this.bufferedRequestCount=0,this.corkedRequestsFree=new f(this)}function y(e){if(u=u||j(/*! ./_stream_duplex */"./node_modules/readable-stream/lib/_stream_duplex.js"),!(c.call(y,this)||this instanceof u))return new y(e);this._writableState=new m(e,this),this.writable=!0,e&&("function"==typeof e.write&&(this._write=e.write),"function"==typeof e.writev&&(this._writev=e.writev),"function"==typeof e.destroy&&(this._destroy=e.destroy),"function"==typeof e.final&&(this._final=e.final)),i.call(this)}function b(e,t,r,n,o,i,s){t.writelen=n,t.writecb=s,t.writing=!0,t.sync=!0,r?e._writev(o,t.onwrite):e._write(o,i,t.onwrite),t.sync=!1}function g(e,t,r,n){r||function(e,t){0===t.length&&t.needDrain&&(t.needDrain=!1,e.emit("drain"))}(e,t),t.pendingcb--,n(),E(e,t)}function v(e,t){t.bufferProcessing=!0;var r=t.bufferedRequest;if(e._writev&&r&&r.next){var n=t.bufferedRequestCount,o=new Array(n),i=t.corkedRequestsFree;i.entry=r;for(var s=0,a=!0;r;)(o[s]=r).isBuf||(a=!1),r=r.next,s+=1;o.allBuffers=a,b(e,t,!0,t.length,o,"",i.finish),t.pendingcb++,t.lastBufferedRequest=null,i.next?(t.corkedRequestsFree=i.next,i.next=null):t.corkedRequestsFree=new f(t),t.bufferedRequestCount=0}else{for(;r;){var u=r.chunk,d=r.encoding,l=r.callback;if(b(e,t,!1,t.objectMode?1:u.length,u,d,l),r=r.next,t.bufferedRequestCount--,t.writing)break}null===r&&(t.lastBufferedRequest=null)}t.bufferedRequest=r,t.bufferProcessing=!1}function _(e){return e.ending&&0===e.length&&null===e.bufferedRequest&&!e.finished&&!e.writing}function w(t,r){t._final(function(e){r.pendingcb--,e&&t.emit("error",e),r.prefinished=!0,t.emit("prefinish"),E(t,r)})}function E(e,t){var r=_(t);return r&&(function(e,t){t.prefinished||t.finalCalled||("function"==typeof e._final?(t.pendingcb++,t.finalCalled=!0,a.nextTick(w,e,t)):(t.prefinished=!0,e.emit("prefinish")))}(e,t),0===t.pendingcb&&(t.finished=!0,e.emit("finish"))),r}n.inherits(y,i),m.prototype.getBuffer=function(){for(var e=this.bufferedRequest,t=[];e;)t.push(e),e=e.next;return t},function(){try{Object.defineProperty(m.prototype,"buffer",{get:o.deprecate(function(){return this.getBuffer()},"_writableState.buffer is deprecated. Use _writableState.getBuffer instead.","DEP0003")})}catch(e){}}(),"function"==typeof Symbol&&Symbol.hasInstance&&"function"==typeof Function.prototype[Symbol.hasInstance]?(c=Function.prototype[Symbol.hasInstance],Object.defineProperty(y,Symbol.hasInstance,{value:function(e){return!!c.call(this,e)||this===y&&(e&&e._writableState instanceof m)}})):c=function(e){return e instanceof this},y.prototype.pipe=function(){this.emit("error",new Error("Cannot pipe, not readable"))},y.prototype.write=function(e,t,r){var n=this._writableState,o=!1,i=!n.objectMode&&function(e){return l.isBuffer(e)||e instanceof s}(e);return i&&!l.isBuffer(e)&&(e=function(e){return l.from(e)}(e)),"function"==typeof t&&(r=t,t=null),t=i?"buffer":t||n.defaultEncoding,"function"!=typeof r&&(r=h),n.ended?function(e,t){var r=new Error("write after end");e.emit("error",r),a.nextTick(t,r)}(this,r):(i||function(e,t,r,n){var o=!0,i=!1;return null===r?i=new TypeError("May not write null values to stream"):"string"==typeof r||void 0===r||t.objectMode||(i=new TypeError("Invalid non-string/buffer chunk")),i&&(e.emit("error",i),a.nextTick(n,i),o=!1),o}(this,n,e,r))&&(n.pendingcb++,o=function(e,t,r,n,o,i){if(!r){var s=function(e,t,r){e.objectMode||!1===e.decodeStrings||"string"!=typeof t||(t=l.from(t,r));return t}(t,n,o);n!==s&&(r=!0,o="buffer",n=s)}var a=t.objectMode?1:n.length;t.length+=a;var u=t.length<t.highWaterMark;u||(t.needDrain=!0);if(t.writing||t.corked){var d=t.lastBufferedRequest;t.lastBufferedRequest={chunk:n,encoding:o,isBuf:r,callback:i,next:null},d?d.next=t.lastBufferedRequest:t.bufferedRequest=t.lastBufferedRequest,t.bufferedRequestCount+=1}else b(e,t,!1,a,n,o,i);return u}(this,n,i,e,t,r)),o},y.prototype.cork=function(){this._writableState.corked++},y.prototype.uncork=function(){var e=this._writableState;e.corked&&(e.corked--,e.writing||e.corked||e.finished||e.bufferProcessing||!e.bufferedRequest||v(this,e))},y.prototype.setDefaultEncoding=function(e){if("string"==typeof e&&(e=e.toLowerCase()),!(-1<["hex","utf8","utf-8","ascii","binary","base64","ucs2","ucs-2","utf16le","utf-16le","raw"].indexOf((e+"").toLowerCase())))throw new TypeError("Unknown encoding: "+e);return this._writableState.defaultEncoding=e,this},Object.defineProperty(y.prototype,"writableHighWaterMark",{enumerable:!1,get:function(){return this._writableState.highWaterMark}}),y.prototype._write=function(e,t,r){r(new Error("_write() is not implemented"))},y.prototype._writev=null,y.prototype.end=function(e,t,r){var n=this._writableState;"function"==typeof e?(r=e,t=e=null):"function"==typeof t&&(r=t,t=null),null!=e&&this.write(e,t),n.corked&&(n.corked=1,this.uncork()),n.ending||n.finished||function(e,t,r){t.ending=!0,E(e,t),r&&(t.finished?a.nextTick(r):e.once("finish",r));t.ended=!0,e.writable=!1}(this,n,r)},Object.defineProperty(y.prototype,"destroyed",{get:function(){return void 0!==this._writableState&&this._writableState.destroyed},set:function(e){this._writableState&&(this._writableState.destroyed=e)}}),y.prototype.destroy=p.destroy,y.prototype._undestroy=p.undestroy,y.prototype._destroy=function(e,t){this.end(),t(e)}}).call(this,j(/*! ./../../process/browser.js */"./node_modules/process/browser.js"),j(/*! ./../../timers-browserify/main.js */"./node_modules/timers-browserify/main.js").setImmediate,j(/*! ./../../webpack/buildin/global.js */"./node_modules/webpack/buildin/global.js"))},"./node_modules/readable-stream/lib/internal/streams/BufferList.js":
/*!*************************************************************************!*\
  !*** ./node_modules/readable-stream/lib/internal/streams/BufferList.js ***!
  \*************************************************************************/
/*! no static exports found */function(e,t,r){"use strict";var a=r(/*! safe-buffer */"./node_modules/readable-stream/node_modules/safe-buffer/index.js").Buffer,n=r(/*! util */1);function o(){!function(e,t){if(!(e instanceof t))throw new TypeError("Cannot call a class as a function")}(this,o),this.head=null,this.tail=null,this.length=0}e.exports=(o.prototype.push=function(e){var t={data:e,next:null};0<this.length?this.tail.next=t:this.head=t,this.tail=t,++this.length},o.prototype.unshift=function(e){var t={data:e,next:this.head};0===this.length&&(this.tail=t),this.head=t,++this.length},o.prototype.shift=function(){if(0!==this.length){var e=this.head.data;return 1===this.length?this.head=this.tail=null:this.head=this.head.next,--this.length,e}},o.prototype.clear=function(){this.head=this.tail=null,this.length=0},o.prototype.join=function(e){if(0===this.length)return"";for(var t=this.head,r=""+t.data;t=t.next;)r+=e+t.data;return r},o.prototype.concat=function(e){if(0===this.length)return a.alloc(0);if(1===this.length)return this.head.data;for(var t,r,n,o=a.allocUnsafe(e>>>0),i=this.head,s=0;i;)t=i.data,r=o,n=s,t.copy(r,n),s+=i.data.length,i=i.next;return o},o),n&&n.inspect&&n.inspect.custom&&(e.exports.prototype[n.inspect.custom]=function(){var e=n.inspect({length:this.length});return this.constructor.name+" "+e})},"./node_modules/readable-stream/lib/internal/streams/destroy.js":
/*!**********************************************************************!*\
  !*** ./node_modules/readable-stream/lib/internal/streams/destroy.js ***!
  \**********************************************************************/
/*! no static exports found */function(e,t,r){"use strict";var i=r(/*! process-nextick-args */"./node_modules/process-nextick-args/index.js");function s(e,t){e.emit("error",t)}e.exports={destroy:function(e,t){var r=this,n=this._readableState&&this._readableState.destroyed,o=this._writableState&&this._writableState.destroyed;return n||o?t?t(e):!e||this._writableState&&this._writableState.errorEmitted||i.nextTick(s,this,e):(this._readableState&&(this._readableState.destroyed=!0),this._writableState&&(this._writableState.destroyed=!0),this._destroy(e||null,function(e){!t&&e?(i.nextTick(s,r,e),r._writableState&&(r._writableState.errorEmitted=!0)):t&&t(e)})),this},undestroy:function(){this._readableState&&(this._readableState.destroyed=!1,this._readableState.reading=!1,this._readableState.ended=!1,this._readableState.endEmitted=!1),this._writableState&&(this._writableState.destroyed=!1,this._writableState.ended=!1,this._writableState.ending=!1,this._writableState.finished=!1,this._writableState.errorEmitted=!1)}}},"./node_modules/readable-stream/lib/internal/streams/stream-browser.js":
/*!*****************************************************************************!*\
  !*** ./node_modules/readable-stream/lib/internal/streams/stream-browser.js ***!
  \*****************************************************************************/
/*! no static exports found */function(e,t,r){e.exports=r(/*! events */"./node_modules/events/events.js").EventEmitter},"./node_modules/readable-stream/node_modules/safe-buffer/index.js":
/*!************************************************************************!*\
  !*** ./node_modules/readable-stream/node_modules/safe-buffer/index.js ***!
  \************************************************************************/
/*! no static exports found */function(e,t,r){var n=r(/*! buffer */"./node_modules/buffer/index.js"),o=n.Buffer;function i(e,t){for(var r in e)t[r]=e[r]}function s(e,t,r){return o(e,t,r)}o.from&&o.alloc&&o.allocUnsafe&&o.allocUnsafeSlow?e.exports=n:(i(n,t),t.Buffer=s),i(o,s),s.from=function(e,t,r){if("number"==typeof e)throw new TypeError("Argument must not be a number");return o(e,t,r)},s.alloc=function(e,t,r){if("number"!=typeof e)throw new TypeError("Argument must be a number");var n=o(e);return void 0!==t?"string"==typeof r?n.fill(t,r):n.fill(t):n.fill(0),n},s.allocUnsafe=function(e){if("number"!=typeof e)throw new TypeError("Argument must be a number");return o(e)},s.allocUnsafeSlow=function(e){if("number"!=typeof e)throw new TypeError("Argument must be a number");return n.SlowBuffer(e)}},"./node_modules/readable-stream/passthrough.js":
/*!*****************************************************!*\
  !*** ./node_modules/readable-stream/passthrough.js ***!
  \*****************************************************/
/*! no static exports found */function(e,t,r){e.exports=r(/*! ./readable */"./node_modules/readable-stream/readable-browser.js").PassThrough},"./node_modules/readable-stream/readable-browser.js":
/*!**********************************************************!*\
  !*** ./node_modules/readable-stream/readable-browser.js ***!
  \**********************************************************/
/*! no static exports found */function(e,t,r){(((t=e.exports=r(/*! ./lib/_stream_readable.js */"./node_modules/readable-stream/lib/_stream_readable.js")).Stream=t).Readable=t).Writable=r(/*! ./lib/_stream_writable.js */"./node_modules/readable-stream/lib/_stream_writable.js"),t.Duplex=r(/*! ./lib/_stream_duplex.js */"./node_modules/readable-stream/lib/_stream_duplex.js"),t.Transform=r(/*! ./lib/_stream_transform.js */"./node_modules/readable-stream/lib/_stream_transform.js"),t.PassThrough=r(/*! ./lib/_stream_passthrough.js */"./node_modules/readable-stream/lib/_stream_passthrough.js")},"./node_modules/readable-stream/transform.js":
/*!***************************************************!*\
  !*** ./node_modules/readable-stream/transform.js ***!
  \***************************************************/
/*! no static exports found */function(e,t,r){e.exports=r(/*! ./readable */"./node_modules/readable-stream/readable-browser.js").Transform},"./node_modules/readable-stream/writable-browser.js":
/*!**********************************************************!*\
  !*** ./node_modules/readable-stream/writable-browser.js ***!
  \**********************************************************/
/*! no static exports found */function(e,t,r){e.exports=r(/*! ./lib/_stream_writable.js */"./node_modules/readable-stream/lib/_stream_writable.js")},"./node_modules/resumer/index.js":
/*!***************************************!*\
  !*** ./node_modules/resumer/index.js ***!
  \***************************************/
/*! no static exports found */function(r,e,n){(function(e,t){var s=n(/*! through */"./node_modules/through/index.js"),a=void 0!==e?e:t.nextTick;r.exports=function(e,t){var r=s(e,t);r.pause();var n=r.resume,o=r.pause,i=!1;return r.pause=function(){return i=!0,o.apply(this,arguments)},r.resume=function(){return i=!1,n.apply(this,arguments)},a(function(){i||r.resume()}),r}}).call(this,n(/*! ./../timers-browserify/main.js */"./node_modules/timers-browserify/main.js").setImmediate,n(/*! ./../process/browser.js */"./node_modules/process/browser.js"))},"./node_modules/safe-buffer/index.js":
/*!*******************************************!*\
  !*** ./node_modules/safe-buffer/index.js ***!
  \*******************************************/
/*! no static exports found */function(e,t,r){var n=r(/*! buffer */"./node_modules/buffer/index.js"),o=n.Buffer;function i(e,t){for(var r in e)t[r]=e[r]}function s(e,t,r){return o(e,t,r)}o.from&&o.alloc&&o.allocUnsafe&&o.allocUnsafeSlow?e.exports=n:(i(n,t),t.Buffer=s),s.prototype=Object.create(o.prototype),i(o,s),s.from=function(e,t,r){if("number"==typeof e)throw new TypeError("Argument must not be a number");return o(e,t,r)},s.alloc=function(e,t,r){if("number"!=typeof e)throw new TypeError("Argument must be a number");var n=o(e);return void 0!==t?"string"==typeof r?n.fill(t,r):n.fill(t):n.fill(0),n},s.allocUnsafe=function(e){if("number"!=typeof e)throw new TypeError("Argument must be a number");return o(e)},s.allocUnsafeSlow=function(e){if("number"!=typeof e)throw new TypeError("Argument must be a number");return n.SlowBuffer(e)}},"./node_modules/setimmediate/setImmediate.js":
/*!***************************************************!*\
  !*** ./node_modules/setimmediate/setImmediate.js ***!
  \***************************************************/
/*! no static exports found */function(e,t,r){(function(e,h){!function(r,n){"use strict";if(!r.setImmediate){var o,i,t,s,a=1,u={},d=!1,l=r.document,e=Object.getPrototypeOf&&Object.getPrototypeOf(r);e=e&&e.setTimeout?e:r,o="[object process]"==={}.toString.call(r.process)?function(e){h.nextTick(function(){c(e)})}:function(){if(r.postMessage&&!r.importScripts){var e=!0,t=r.onmessage;return r.onmessage=function(){e=!1},r.postMessage("","*"),r.onmessage=t,e}}()?(s="setImmediate$"+Math.random()+"$",r.addEventListener?r.addEventListener("message",p,!1):r.attachEvent("onmessage",p),function(e){r.postMessage(s+e,"*")}):r.MessageChannel?((t=new MessageChannel).port1.onmessage=function(e){c(e.data)},function(e){t.port2.postMessage(e)}):l&&"onreadystatechange"in l.createElement("script")?(i=l.documentElement,function(e){var t=l.createElement("script");t.onreadystatechange=function(){c(e),t.onreadystatechange=null,i.removeChild(t),t=null},i.appendChild(t)}):function(e){setTimeout(c,0,e)},e.setImmediate=function(e){"function"!=typeof e&&(e=new Function(""+e));for(var t=new Array(arguments.length-1),r=0;r<t.length;r++)t[r]=arguments[r+1];var n={callback:e,args:t};return u[a]=n,o(a),a++},e.clearImmediate=f}function f(e){delete u[e]}function c(e){if(d)setTimeout(c,0,e);else{var t=u[e];if(t){d=!0;try{!function(e){var t=e.callback,r=e.args;switch(r.length){case 0:t();break;case 1:t(r[0]);break;case 2:t(r[0],r[1]);break;case 3:t(r[0],r[1],r[2]);break;default:t.apply(n,r)}}(t)}finally{f(e),d=!1}}}}function p(e){e.source===r&&"string"==typeof e.data&&0===e.data.indexOf(s)&&c(+e.data.slice(s.length))}}("undefined"==typeof self?void 0===e?this:e:self)}).call(this,r(/*! ./../webpack/buildin/global.js */"./node_modules/webpack/buildin/global.js"),r(/*! ./../process/browser.js */"./node_modules/process/browser.js"))},"./node_modules/stream-browserify/index.js":
/*!*************************************************!*\
  !*** ./node_modules/stream-browserify/index.js ***!
  \*************************************************/
/*! no static exports found */function(e,t,r){e.exports=n;var l=r(/*! events */"./node_modules/events/events.js").EventEmitter;function n(){l.call(this)}r(/*! inherits */"./node_modules/inherits/inherits_browser.js")(n,l),n.Readable=r(/*! readable-stream/readable.js */"./node_modules/readable-stream/readable-browser.js"),n.Writable=r(/*! readable-stream/writable.js */"./node_modules/readable-stream/writable-browser.js"),n.Duplex=r(/*! readable-stream/duplex.js */"./node_modules/readable-stream/duplex-browser.js"),n.Transform=r(/*! readable-stream/transform.js */"./node_modules/readable-stream/transform.js"),n.PassThrough=r(/*! readable-stream/passthrough.js */"./node_modules/readable-stream/passthrough.js"),(n.Stream=n).prototype.pipe=function(t,e){var r=this;function n(e){t.writable&&!1===t.write(e)&&r.pause&&r.pause()}function o(){r.readable&&r.resume&&r.resume()}r.on("data",n),t.on("drain",o),t._isStdio||e&&!1===e.end||(r.on("end",s),r.on("close",a));var i=!1;function s(){i||(i=!0,t.end())}function a(){i||(i=!0,"function"==typeof t.destroy&&t.destroy())}function u(e){if(d(),0===l.listenerCount(this,"error"))throw e}function d(){r.removeListener("data",n),t.removeListener("drain",o),r.removeListener("end",s),r.removeListener("close",a),r.removeListener("error",u),t.removeListener("error",u),r.removeListener("end",d),r.removeListener("close",d),t.removeListener("close",d)}return r.on("error",u),t.on("error",u),r.on("end",d),r.on("close",d),t.on("close",d),t.emit("pipe",r),t}},"./node_modules/string.prototype.trim/implementation.js":
/*!**************************************************************!*\
  !*** ./node_modules/string.prototype.trim/implementation.js ***!
  \**************************************************************/
/*! no static exports found */function(e,t,r){"use strict";var n=r(/*! function-bind */"./node_modules/function-bind/index.js"),o=r(/*! es-abstract/es5 */"./node_modules/es-abstract/es5.js"),i=n.call(Function.call,String.prototype.replace),s=/^[\x09\x0A\x0B\x0C\x0D\x20\xA0\u1680\u180E\u2000\u2001\u2002\u2003\u2004\u2005\u2006\u2007\u2008\u2009\u200A\u202F\u205F\u3000\u2028\u2029\uFEFF]+/,a=/[\x09\x0A\x0B\x0C\x0D\x20\xA0\u1680\u180E\u2000\u2001\u2002\u2003\u2004\u2005\u2006\u2007\u2008\u2009\u200A\u202F\u205F\u3000\u2028\u2029\uFEFF]+$/;e.exports=function(){var e=o.ToString(o.CheckObjectCoercible(this));return i(i(e,s,""),a,"")}},"./node_modules/string.prototype.trim/index.js":
/*!*****************************************************!*\
  !*** ./node_modules/string.prototype.trim/index.js ***!
  \*****************************************************/
/*! no static exports found */function(e,t,r){"use strict";var n=r(/*! function-bind */"./node_modules/function-bind/index.js"),o=r(/*! define-properties */"./node_modules/define-properties/index.js"),i=r(/*! ./implementation */"./node_modules/string.prototype.trim/implementation.js"),s=r(/*! ./polyfill */"./node_modules/string.prototype.trim/polyfill.js"),a=r(/*! ./shim */"./node_modules/string.prototype.trim/shim.js"),u=n.call(Function.call,s());o(u,{getPolyfill:s,implementation:i,shim:a}),e.exports=u},"./node_modules/string.prototype.trim/polyfill.js":
/*!********************************************************!*\
  !*** ./node_modules/string.prototype.trim/polyfill.js ***!
  \********************************************************/
/*! no static exports found */function(e,t,r){"use strict";var n=r(/*! ./implementation */"./node_modules/string.prototype.trim/implementation.js");e.exports=function(){return String.prototype.trim&&"​"==="​".trim()?String.prototype.trim:n}},"./node_modules/string.prototype.trim/shim.js":
/*!****************************************************!*\
  !*** ./node_modules/string.prototype.trim/shim.js ***!
  \****************************************************/
/*! no static exports found */function(e,t,r){"use strict";var n=r(/*! define-properties */"./node_modules/define-properties/index.js"),o=r(/*! ./polyfill */"./node_modules/string.prototype.trim/polyfill.js");e.exports=function(){var e=o();return n(String.prototype,{trim:e},{trim:function(){return String.prototype.trim!==e}}),e}},"./node_modules/string_decoder/lib/string_decoder.js":
/*!***********************************************************!*\
  !*** ./node_modules/string_decoder/lib/string_decoder.js ***!
  \***********************************************************/
/*! no static exports found */function(e,t,r){"use strict";var n=r(/*! safe-buffer */"./node_modules/safe-buffer/index.js").Buffer,o=n.isEncoding||function(e){switch((e=""+e)&&e.toLowerCase()){case"hex":case"utf8":case"utf-8":case"ascii":case"binary":case"base64":case"ucs2":case"ucs-2":case"utf16le":case"utf-16le":case"raw":return!0;default:return!1}};function i(e){var t;switch(this.encoding=function(e){var t=function(e){if(!e)return"utf8";for(var t;;)switch(e){case"utf8":case"utf-8":return"utf8";case"ucs2":case"ucs-2":case"utf16le":case"utf-16le":return"utf16le";case"latin1":case"binary":return"latin1";case"base64":case"ascii":case"hex":return e;default:if(t)return;e=(""+e).toLowerCase(),t=!0}}(e);if("string"!=typeof t&&(n.isEncoding===o||!o(e)))throw new Error("Unknown encoding: "+e);return t||e}(e),this.encoding){case"utf16le":this.text=u,this.end=d,t=4;break;case"utf8":this.fillLast=a,t=4;break;case"base64":this.text=l,this.end=f,t=3;break;default:return this.write=c,void(this.end=p)}this.lastNeed=0,this.lastTotal=0,this.lastChar=n.allocUnsafe(t)}function s(e){return e<=127?0:e>>5==6?2:e>>4==14?3:e>>3==30?4:e>>6==2?-1:-2}function a(e){var t=this.lastTotal-this.lastNeed,r=function(e,t){if(128!=(192&t[0]))return e.lastNeed=0,"�";if(1<e.lastNeed&&1<t.length){if(128!=(192&t[1]))return e.lastNeed=1,"�";if(2<e.lastNeed&&2<t.length&&128!=(192&t[2]))return e.lastNeed=2,"�"}}(this,e);return void 0!==r?r:this.lastNeed<=e.length?(e.copy(this.lastChar,t,0,this.lastNeed),this.lastChar.toString(this.encoding,0,this.lastTotal)):(e.copy(this.lastChar,t,0,e.length),void(this.lastNeed-=e.length))}function u(e,t){if((e.length-t)%2!=0)return this.lastNeed=1,this.lastTotal=2,this.lastChar[0]=e[e.length-1],e.toString("utf16le",t,e.length-1);var r=e.toString("utf16le",t);if(r){var n=r.charCodeAt(r.length-1);if(55296<=n&&n<=56319)return this.lastNeed=2,this.lastTotal=4,this.lastChar[0]=e[e.length-2],this.lastChar[1]=e[e.length-1],r.slice(0,-1)}return r}function d(e){var t=e&&e.length?this.write(e):"";if(this.lastNeed){var r=this.lastTotal-this.lastNeed;return t+this.lastChar.toString("utf16le",0,r)}return t}function l(e,t){var r=(e.length-t)%3;return 0==r?e.toString("base64",t):(this.lastNeed=3-r,this.lastTotal=3,1==r?this.lastChar[0]=e[e.length-1]:(this.lastChar[0]=e[e.length-2],this.lastChar[1]=e[e.length-1]),e.toString("base64",t,e.length-r))}function f(e){var t=e&&e.length?this.write(e):"";return this.lastNeed?t+this.lastChar.toString("base64",0,3-this.lastNeed):t}function c(e){return e.toString(this.encoding)}function p(e){return e&&e.length?this.write(e):""}(t.StringDecoder=i).prototype.write=function(e){if(0===e.length)return"";var t,r;if(this.lastNeed){if(void 0===(t=this.fillLast(e)))return"";r=this.lastNeed,this.lastNeed=0}else r=0;return r<e.length?t?t+this.text(e,r):this.text(e,r):t||""},i.prototype.end=function(e){var t=e&&e.length?this.write(e):"";return this.lastNeed?t+"�":t},i.prototype.text=function(e,t){var r=function(e,t,r){var n=t.length-1;if(n<r)return 0;var o=s(t[n]);if(0<=o)return 0<o&&(e.lastNeed=o-1),o;if(--n<r||-2===o)return 0;if(0<=(o=s(t[n])))return 0<o&&(e.lastNeed=o-2),o;if(--n<r||-2===o)return 0;if(0<=(o=s(t[n])))return 0<o&&(2===o?o=0:e.lastNeed=o-3),o;return 0}(this,e,t);if(!this.lastNeed)return e.toString("utf8",t);this.lastTotal=r;var n=e.length-(r-this.lastNeed);return e.copy(this.lastChar,0,n),e.toString("utf8",t,n)},i.prototype.fillLast=function(e){if(this.lastNeed<=e.length)return e.copy(this.lastChar,this.lastTotal-this.lastNeed,0,this.lastNeed),this.lastChar.toString(this.encoding,0,this.lastTotal);e.copy(this.lastChar,this.lastTotal-this.lastNeed,0,e.length),this.lastNeed-=e.length}},"./node_modules/tape/index.js":
/*!************************************!*\
  !*** ./node_modules/tape/index.js ***!
  \************************************/
/*! no static exports found */function(p,h,m){(function(s,e){var r,n=m(/*! defined */"./node_modules/tape/node_modules/defined/index.js"),a=m(/*! ./lib/default_stream */"./node_modules/tape/lib/default_stream.js"),u=m(/*! ./lib/test */"./node_modules/tape/lib/test.js"),d=m(/*! ./lib/results */"./node_modules/tape/lib/results.js"),o=m(/*! through */"./node_modules/through/index.js"),l=void 0!==s&&s&&"function"==typeof s.on&&!0!==s.browser,f=void 0!==s&&s&&"function"==typeof s.exit;void 0!==e||s.nextTick;function t(){return i().apply(this,arguments)}function i(e){return(e=e||{}).autoclose=!l,r=r||function(e){e=e||{};var o=c({autoclose:n(e.autoclose,!1)}),t=o.createStream({objectMode:e.objectMode}),r=t.pipe(e.stream||a());l&&r.on("error",function(e){o._exitCode=1});var i=!1;return t.on("end",function(){i=!0}),!1===e.exit||l&&f&&s.on("exit",function(e){if(0===e){if(!i)for(var t=o._results._only,r=0;r<o._tests.length;r++){var n=o._tests[r];t&&n!==t||n._exit()}o.close(),s.exit(e||o._exitCode)}}),o}(e)}function c(e){e=e||{};var o=d();!1!==e.autoclose&&o.once("done",function(){o.close()});var i=function(e,t,r){var n=new u(e,t,r);return i._tests.push(n),function t(e){e.on("test",function(e){t(e)}),e.on("result",function(e){e.todo||e.ok||"string"==typeof e||(i._exitCode=1)})}(n),o.push(n),n};i._results=o,i._tests=[],i.createStream=function(e){return o.createStream(e)},i.onFinish=function(e){o.on("done",e)};var t=!(i.onFailure=function(e){o.on("fail",e)});return i.only=function(){if(t)throw new Error("there can only be one only test");t=!0;var e=i.apply(null,arguments);return o.only(e),e},i._exitCode=0,i.close=function(){o.close()},i}(h=p.exports=(t.only=function(){return i().only.apply(this,arguments)},t.createStream=function(e){if(e=e||{},r)return r.createStream(e);var t=o();return i({stream:t,objectMode:e.objectMode}),t},t.onFinish=function(){return i().onFinish.apply(this,arguments)},t.onFailure=function(){return i().onFailure.apply(this,arguments)},t.getHarness=i,t)).createHarness=c,h.Test=u,(h.test=h).test.skip=u.skip}).call(this,m(/*! ./../process/browser.js */"./node_modules/process/browser.js"),m(/*! ./../timers-browserify/main.js */"./node_modules/timers-browserify/main.js").setImmediate)},"./node_modules/tape/lib/default_stream.js":
/*!*************************************************!*\
  !*** ./node_modules/tape/lib/default_stream.js ***!
  \*************************************************/
/*! no static exports found */function(t,e,n){(function(e){var r=n(/*! through */"./node_modules/through/index.js"),i=n(/*! fs */"./node_modules/node-libs-browser/mock/empty.js");t.exports=function(){var n="",t=r(function(e){for(var t=0;t<e.length;t++){var r="string"==typeof e?e.charAt(t):String.fromCharCode(e[t]);"\n"===r?o():n+=r}},o);return t;function o(){if(i.writeSync&&/^win/.test(e.platform))try{i.writeSync(1,n+"\n")}catch(e){t.emit("error",e)}else try{console.log(n)}catch(e){t.emit("error",e)}n=""}}}).call(this,n(/*! ./../../process/browser.js */"./node_modules/process/browser.js"))},"./node_modules/tape/lib/results.js":
/*!******************************************!*\
  !*** ./node_modules/tape/lib/results.js ***!
  \******************************************/
/*! no static exports found */function(b,e,g){(function(e,t){var f=g(/*! defined */"./node_modules/tape/node_modules/defined/index.js"),r=g(/*! events */"./node_modules/events/events.js").EventEmitter,n=g(/*! inherits */"./node_modules/inherits/inherits_browser.js"),o=g(/*! through */"./node_modules/through/index.js"),a=g(/*! resumer */"./node_modules/resumer/index.js"),c=g(/*! object-inspect */"./node_modules/object-inspect/index.js"),i=g(/*! function-bind */"./node_modules/function-bind/index.js"),p=g(/*! has */"./node_modules/has/src/index.js"),s=i.call(Function.call,RegExp.prototype.test),u=/\:|\-|\?/,d=void 0!==e?e:t.nextTick;function h(e){return String(e).replace(/\s+/g," ")}function l(){if(!(this instanceof l))return new l;this.count=0,this.fail=0,this.pass=0,this.todo=0,this._stream=o(),this.tests=[],this._only=null,this._isRunning=!1}function m(e){if(!e._only)return e.tests.shift();do{var t=e.tests.shift();if(t&&e._only===t)return t}while(0!==e.tests.length)}function y(e){return s(u,e)}n(b.exports=l,r),l.prototype.createStream=function(e){var i,r=this,s=0;return(e=e||{}).objectMode?(i=o(),r.on("_push",function t(r,n){n=n||{};var o=s++;r.once("prerun",function(){var e={type:"test",name:r.name,id:o,skip:r._skip,todo:r._todo};p(n,"parent")&&(e.parent=n.parent),i.queue(e)}),r.on("test",function(e){t(e,{parent:o})}),r.on("result",function(e){e.test=o,e.type="assert",i.queue(e)}),r.on("end",function(){i.queue({type:"end",test:o})})}),r.on("done",function(){i.queue(null)})):((i=a()).queue("TAP version 13\n"),r._stream.pipe(i)),this._isRunning||(this._isRunning=!0,d(function e(){for(var t;t=m(r);)if(t.run(),!t.ended)return t.once("end",function(){d(e)});r.emit("done")})),i},l.prototype.push=function(e){this.tests.push(e),this._watch(e),this.emit("_push",e)},l.prototype.only=function(e){this._only=e},l.prototype._watch=function(t){function r(e){n._stream.queue(e)}var n=this;t.once("prerun",function(){var e="";t._skip?e="SKIP ":t._todo&&(e="TODO "),r("# "+e+h(t.name)+"\n")}),t.on("result",function(e){"string"!=typeof e?(r(function(e,t){var r="";r+=(e.ok?"ok ":"not ok ")+t,r+=e.name?" "+h(e.name):"",e.skip?r+=" # SKIP"+("string"==typeof e.skip?" "+h(e.skip):""):e.todo&&(r+=" # TODO"+("string"==typeof e.todo?" "+h(e.todo):""));if(r+="\n",e.ok)return r;var n="    ";if(r+="  ---\n",r+=n+"operator: "+e.operator+"\n",p(e,"expected")||p(e,"actual")){var o=c(e.expected,{depth:e.objectPrintDepth}),i=c(e.actual,{depth:e.objectPrintDepth});65<Math.max(o.length,i.length)||y(o)||y(i)?(r+="    expected: |-\n      "+o+"\n",r+="    actual: |-\n      "+i+"\n"):(r+=n+"expected: "+o+"\n",r+=n+"actual:   "+i+"\n")}e.at&&(r+=n+"at: "+e.at+"\n");var s=!e.actual||"object"!=typeof e.actual&&"function"!=typeof e.actual?void 0:e.actual.stack,a=e.error&&e.error.stack,u=f(s,a);if(u){var d=String(u).split("\n");r+=n+"stack: |-\n";for(var l=0;l<d.length;l++)r+=n+"  "+d[l]+"\n"}return r+="  ...\n"}(e,n.count+1)),n.count++,e.ok||e.todo?n.pass++:(n.fail++,n.emit("fail"))):r("# "+e+"\n")}),t.on("test",function(e){n._watch(e)})},l.prototype.close=function(){var t=this;t.closed&&t._stream.emit("error",new Error("ALREADY CLOSED")),t.closed=!0;function e(e){t._stream.queue(e)}e("\n1.."+t.count+"\n"),e("# tests "+t.count+"\n"),e("# pass  "+(t.pass+t.todo)+"\n"),t.todo&&e("# todo  "+t.todo+"\n"),t.fail?e("# fail  "+t.fail+"\n"):e("\n# ok\n"),t._stream.queue(null)}}).call(this,g(/*! ./../../timers-browserify/main.js */"./node_modules/timers-browserify/main.js").setImmediate,g(/*! ./../../process/browser.js */"./node_modules/process/browser.js"))},"./node_modules/tape/lib/test.js":
/*!***************************************!*\
  !*** ./node_modules/tape/lib/test.js ***!
  \***************************************/
/*! no static exports found */function(v,e,_){(function(e,s,c){var o=_(/*! deep-equal */"./node_modules/deep-equal/index.js"),p=_(/*! defined */"./node_modules/tape/node_modules/defined/index.js"),h=_(/*! path */"./node_modules/path-browserify/index.js"),t=_(/*! inherits */"./node_modules/inherits/inherits_browser.js"),r=_(/*! events */"./node_modules/events/events.js").EventEmitter,m=_(/*! has */"./node_modules/has/src/index.js"),n=_(/*! string.prototype.trim */"./node_modules/string.prototype.trim/index.js"),i=_(/*! function-bind */"./node_modules/function-bind/index.js"),a=_(/*! for-each */"./node_modules/for-each/index.js"),u=i.call(Function.call,Object.prototype.propertyIsEnumerable),d=i.call(Function.call,String.prototype.toLowerCase);v.exports=g;var y=void 0!==e?e:s.nextTick,l=setTimeout,f=clearTimeout;t(g,r);var b=function(e,t,r){for(var n,o="(anonymous)",i={},s=0;s<arguments.length;s++){var a=arguments[s],u=typeof a;"string"==u?o=a:"object"==u?i=a||i:"function"==u&&(n=a)}return{name:o,opts:i,cb:n}};function g(e,t,r){if(!(this instanceof g))return new g(e,t,r);var n=b(e,t,r);this.readable=!0,this.name=n.name||"(anonymous)",this.assertCount=0,this.pendingCount=0,this._skip=n.opts.skip||!1,this._todo=n.opts.todo||!1,this._timeout=n.opts.timeout,this._plan=void 0,this._cb=n.cb,this._progeny=[],this._ok=!0;var o=s.env.NODE_TAPE_OBJECT_PRINT_DEPTH;for(var i in n.opts.objectPrintDepth?this._objectPrintDepth=n.opts.objectPrintDepth:o?"infinity"===d(o)?this._objectPrintDepth=1/0:this._objectPrintDepth=o:this._objectPrintDepth=5,this)this[i]=function(e,t){return"function"==typeof t?function(){return t.apply(e,arguments)}:t}(this,this[i])}g.prototype.run=function(){if(this.emit("prerun"),!this._cb||this._skip)return this._end();null!=this._timeout&&this.timeoutAfter(this._timeout),this._cb(this),this.emit("run")},g.prototype.test=function(e,t,r){var n=this,o=new g(e,t,r);this._progeny.push(o),this.pendingCount++,this.emit("test",o),o.on("prerun",function(){n.assertCount++}),n._pendingAsserts()||y(function(){n._end()}),y(function(){n._plan||n.pendingCount!=n._progeny.length||n._end()})},g.prototype.comment=function(e){var t=this;a(n(e).split("\n"),function(e){t.emit("result",n(e).replace(/^#\s*/,""))})},g.prototype.plan=function(e){this._plan=e,this.emit("plan",e)},g.prototype.timeoutAfter=function(e){if(!e)throw new Error("timeoutAfter requires a timespan");var t=this,r=l(function(){t.fail("test timed out after "+e+"ms"),t.end()},e);this.once("end",function(){f(r)})},g.prototype.end=function(e){1<=arguments.length&&e&&this.ifError(e),this.calledEnd&&this.fail(".end() called twice"),this.calledEnd=!0,this._end()},g.prototype._end=function(e){var t=this;if(this._progeny.length){var r=this._progeny.shift();return r.on("end",function(){t._end()}),void r.run()}this.ended||this.emit("end");var n=this._pendingAsserts();!this._planError&&void 0!==this._plan&&n&&(this._planError=!0,this.fail("plan != count",{expected:this._plan,actual:this.assertCount})),this.ended=!0},g.prototype._exit=function(){void 0===this._plan||this._planError||this.assertCount===this._plan?this.ended||this.fail("test exited without ending",{exiting:!0}):(this._planError=!0,this.fail("plan != count",{expected:this._plan,actual:this.assertCount,exiting:!0}))},g.prototype._pendingAsserts=function(){return void 0===this._plan?1:this._plan-(this._progeny.length+this.assertCount)},g.prototype._assert=function(e,t){var r=this,n=t.extra||{};e=!!e||!!n.skip;var o={id:r.assertCount++,ok:e,skip:p(n.skip,t.skip),todo:p(n.todo,t.todo,r._todo),name:p(n.message,t.message,"(unnamed assert)"),operator:p(n.operator,t.operator),objectPrintDepth:r._objectPrintDepth};if((m(t,"actual")||m(n,"actual"))&&(o.actual=p(n.actual,t.actual)),(m(t,"expected")||m(n,"expected"))&&(o.expected=p(n.expected,t.expected)),this._ok=!(!this._ok||!e),e||o.todo||(o.error=p(n.error,t.error,new Error(o.name))),!e)for(var i=(new Error("exception").stack||"").split("\n"),s=c+h.sep,a=0;a<i.length;a++){var u=/^(?:[^\s]*\s*\bat\s+)(?:(.*)\s+\()?((?:\/|[a-zA-Z]:\\)[^:\)]+:(\d+)(?::(\d+))?)/.exec(i[a]);if(u){var d=u[1]||"<anonymous>",l=u[2];if(l.slice(0,s.length)!==s){o.functionName=d.split(/\s+/)[0],o.file=l,o.line=Number(u[3]),u[4]&&(o.column=Number(u[4])),o.at=d+" ("+l+")";break}}}r.emit("result",o);var f=r._pendingAsserts();f||(n.exiting?r._end():y(function(){r._end()})),!r._planError&&f<0&&(r._planError=!0,r.fail("plan != count",{expected:r._plan,actual:r._plan-f}))},g.prototype.fail=function(e,t){this._assert(!1,{message:e,operator:"fail",extra:t})},g.prototype.pass=function(e,t){this._assert(!0,{message:e,operator:"pass",extra:t})},g.prototype.skip=function(e,t){this._assert(!0,{message:e,operator:"skip",skip:!0,extra:t})},g.prototype.ok=g.prototype.true=g.prototype.assert=function(e,t,r){this._assert(e,{message:p(t,"should be truthy"),operator:"ok",expected:!0,actual:e,extra:r})},g.prototype.notOk=g.prototype.false=g.prototype.notok=function(e,t,r){this._assert(!e,{message:p(t,"should be falsy"),operator:"notOk",expected:!1,actual:e,extra:r})},g.prototype.error=g.prototype.ifError=g.prototype.ifErr=g.prototype.iferror=function(e,t,r){this._assert(!e,{message:p(t,String(e)),operator:"error",actual:e,extra:r})},g.prototype.equal=g.prototype.equals=g.prototype.isEqual=g.prototype.is=g.prototype.strictEqual=g.prototype.strictEquals=function(e,t,r,n){this._assert(e===t,{message:p(r,"should be equal"),operator:"equal",actual:e,expected:t,extra:n})},g.prototype.notEqual=g.prototype.notEquals=g.prototype.notStrictEqual=g.prototype.notStrictEquals=g.prototype.isNotEqual=g.prototype.isNot=g.prototype.not=g.prototype.doesNotEqual=g.prototype.isInequal=function(e,t,r,n){this._assert(e!==t,{message:p(r,"should not be equal"),operator:"notEqual",actual:e,expected:t,extra:n})},g.prototype.deepEqual=g.prototype.deepEquals=g.prototype.isEquivalent=g.prototype.same=function(e,t,r,n){this._assert(o(e,t,{strict:!0}),{message:p(r,"should be equivalent"),operator:"deepEqual",actual:e,expected:t,extra:n})},g.prototype.deepLooseEqual=g.prototype.looseEqual=g.prototype.looseEquals=function(e,t,r,n){this._assert(o(e,t),{message:p(r,"should be equivalent"),operator:"deepLooseEqual",actual:e,expected:t,extra:n})},g.prototype.notDeepEqual=g.prototype.notDeepEquals=g.prototype.notEquivalent=g.prototype.notDeeply=g.prototype.notSame=g.prototype.isNotDeepEqual=g.prototype.isNotDeeply=g.prototype.isNotEquivalent=g.prototype.isInequivalent=function(e,t,r,n){this._assert(!o(e,t,{strict:!0}),{message:p(r,"should not be equivalent"),operator:"notDeepEqual",actual:e,expected:t,extra:n})},g.prototype.notDeepLooseEqual=g.prototype.notLooseEqual=g.prototype.notLooseEquals=function(e,t,r,n){this._assert(!o(e,t),{message:p(r,"should be equivalent"),operator:"notDeepLooseEqual",actual:e,expected:t,extra:n})},g.prototype.throws=function(e,t,r,n){"string"==typeof t&&(r=t,t=void 0);var o=void 0;try{e()}catch(e){if(o={error:e},!(null==e||u(e,"message")&&m(e,"message"))){var i=e.message;delete e.message,e.message=i}}var s=o;t instanceof RegExp&&(s=t.test(o&&o.error),t=String(t)),"function"==typeof t&&o&&(s=o.error instanceof t,o.error=o.error.constructor),this._assert("function"==typeof e&&s,{message:p(r,"should throw"),operator:"throws",actual:o&&o.error,expected:t,error:!s&&o&&o.error,extra:n})},g.prototype.doesNotThrow=function(e,t,r,n){"string"==typeof t&&(r=t,t=void 0);var o=void 0;try{e()}catch(e){o={error:e}}this._assert(!o,{message:p(r,"should not throw"),operator:"throws",actual:o&&o.error,expected:t,error:o&&o.error,extra:n})},g.skip=function(e,t,r){var n=b.apply(null,arguments);return n.opts.skip=!0,g(n.name,n.opts,n.cb)}}).call(this,_(/*! ./../../timers-browserify/main.js */"./node_modules/timers-browserify/main.js").setImmediate,_(/*! ./../../process/browser.js */"./node_modules/process/browser.js"),"/")},"./node_modules/tape/node_modules/defined/index.js":
/*!*********************************************************!*\
  !*** ./node_modules/tape/node_modules/defined/index.js ***!
  \*********************************************************/
/*! no static exports found */function(e,t){e.exports=function(){for(var e=0;e<arguments.length;e++)if(void 0!==arguments[e])return arguments[e]}},"./node_modules/through/index.js":
/*!***************************************!*\
  !*** ./node_modules/through/index.js ***!
  \***************************************/
/*! no static exports found */function(t,e,r){(function(d){var l=r(/*! stream */"./node_modules/stream-browserify/index.js");function e(t,r,e){t=t||function(e){this.queue(e)},r=r||function(){this.queue(null)};var n=!1,o=!1,i=[],s=!1,a=new l;function u(){for(;i.length&&!a.paused;){var e=i.shift();if(null===e)return a.emit("end");a.emit("data",e)}}return a.readable=a.writable=!0,a.paused=!1,a.autoDestroy=!(e&&!1===e.autoDestroy),a.write=function(e){return t.call(this,e),!a.paused},a.queue=a.push=function(e){return s||(null===e&&(s=!0),i.push(e),u()),a},a.on("end",function(){a.readable=!1,!a.writable&&a.autoDestroy&&d.nextTick(function(){a.destroy()})}),a.end=function(e){if(!n)return n=!0,arguments.length&&a.write(e),a.writable=!1,r.call(a),!a.readable&&a.autoDestroy&&a.destroy(),a},a.destroy=function(){if(!o)return n=o=!0,i.length=0,a.writable=a.readable=!1,a.emit("close"),a},a.pause=function(){if(!a.paused)return a.paused=!0,a},a.resume=function(){return a.paused&&(a.paused=!1,a.emit("resume")),u(),a.paused||a.emit("drain"),a},a}t.exports=e,e.through=e}).call(this,r(/*! ./../process/browser.js */"./node_modules/process/browser.js"))},"./node_modules/timers-browserify/main.js":
/*!************************************************!*\
  !*** ./node_modules/timers-browserify/main.js ***!
  \************************************************/
/*! no static exports found */function(e,o,i){(function(e){var t=void 0!==e&&e||"undefined"!=typeof self&&self||window,r=Function.prototype.apply;function n(e,t){this._id=e,this._clearFn=t}o.setTimeout=function(){return new n(r.call(setTimeout,t,arguments),clearTimeout)},o.setInterval=function(){return new n(r.call(setInterval,t,arguments),clearInterval)},o.clearTimeout=o.clearInterval=function(e){e&&e.close()},n.prototype.unref=n.prototype.ref=function(){},n.prototype.close=function(){this._clearFn.call(t,this._id)},o.enroll=function(e,t){clearTimeout(e._idleTimeoutId),e._idleTimeout=t},o.unenroll=function(e){clearTimeout(e._idleTimeoutId),e._idleTimeout=-1},o._unrefActive=o.active=function(e){clearTimeout(e._idleTimeoutId);var t=e._idleTimeout;0<=t&&(e._idleTimeoutId=setTimeout(function(){e._onTimeout&&e._onTimeout()},t))},i(/*! setimmediate */"./node_modules/setimmediate/setImmediate.js"),o.setImmediate="undefined"!=typeof self&&self.setImmediate||void 0!==e&&e.setImmediate||this&&this.setImmediate,o.clearImmediate="undefined"!=typeof self&&self.clearImmediate||void 0!==e&&e.clearImmediate||this&&this.clearImmediate}).call(this,i(/*! ./../webpack/buildin/global.js */"./node_modules/webpack/buildin/global.js"))},"./node_modules/util-deprecate/browser.js":
/*!************************************************!*\
  !*** ./node_modules/util-deprecate/browser.js ***!
  \************************************************/
/*! no static exports found */function(e,t,r){(function(r){function n(e){try{if(!r.localStorage)return!1}catch(e){return!1}var t=r.localStorage[e];return null!=t&&"true"===String(t).toLowerCase()}e.exports=function(e,t){if(n("noDeprecation"))return e;var r=!1;return function(){if(!r){if(n("throwDeprecation"))throw new Error(t);n("traceDeprecation")?console.trace(t):console.warn(t),r=!0}return e.apply(this,arguments)}}}).call(this,r(/*! ./../webpack/buildin/global.js */"./node_modules/webpack/buildin/global.js"))},"./node_modules/webpack/buildin/global.js":
/*!***********************************!*\
  !*** (webpack)/buildin/global.js ***!
  \***********************************/
/*! no static exports found */function(e,t){var r;r=function(){return this}();try{r=r||new Function("return this")()}catch(e){"object"==typeof window&&(r=window)}e.exports=r},"./src/graph.js":
/*!**********************!*\
  !*** ./src/graph.js ***!
  \**********************/
/*! exports provided: default */function(e,t,r){"use strict";r.r(t);var s="_U_",a="User",u="_multi",d={UNKNOWN:"UNKNOWN",PENDING:"PENDING",RUNNING:"RUNNING",DONE:"DONE",FAILED:"FAILED"};function l(e,t,r,n,o){var i=t||e,s=r||"analysis",a=n||d.UNKNOWN;if(void 0===d[a])throw Error("Unknown status '".concat(a,"' for node ").concat(i,"(id=").concat(e,")"));this.id=e,this.name=i,this.isMulti=0<=s.search(/_multi$/),this.type=this.isMulti?s.substr(0,s.length-u.length):s,this.status=a,this.subxdsm=o}function f(e,t,r,n,o,i){var s=this;if(this.id="link_".concat(e,"_").concat(t),"string"==typeof r){this.name=r,this.vars={},this.name.split(",").forEach(function(e,t){s.vars[t]=e.trim()})}else{this.vars=r;var a=[];for(var u in this.vars)Object.prototype.hasOwnProperty.call(this.vars,u)&&a.push(this.vars[u]);this.name=a.join(", ")}this.row=n,this.col=o,this.iotype=n<o?"in":"out",this.isMulti=i}function c(e,t,r){var n=this;this.nodes=[new l(s,a,"driver")],r&&(this.nodes=[]),this.edges=[],this.chains=[],this.refname=t||"";var o=c.number(e.workflow),i=o.toNum;this.nodesByStep=o.toNode,e.nodes.forEach(function(e){var t=i[e.id];n.nodes.push(new l(e.id,t?"".concat(t,":").concat(e.name):e.name,e.type,e.status,e.subxdsm))},this),this.uid=this.nodes[0].id,e.edges&&e.edges.forEach(function(e){n.addEdge(e.from,e.to,e.vars?e.vars:e.name)},this),e.workflow&&this._makeChaining(e.workflow)}l.prototype.isComposite=function(){return"mdo"===this.type||"sub-optimization"===this.type||"group"===this.type||"implicit-group"===this.type},l.prototype.getSubXdsmId=function(){if(this.isComposite()){var e=this.name.indexOf("_scn-");if(-1!==e)return console.log("Use of <name>_scn-<id> pattern in node.name to detect sub scenario 'scn-<id>' is deprecated. Use node.subxdsm property instead (i.e. node.subxdsm = <id>)"),this.name.substr(e+1);if(this.subxdsm)return this.subxdsm;console.log("".concat("Warning: Sub XDSM id not found. Bad type or name for node: ").concat(JSON.stringify(this)))}return null},f.prototype.addVar=function(e){if("string"==typeof e)""===this.name?this.name=e:this.name+=", ".concat(e),this.vars[this.vars.length]=e;else for(var t in e)if(Object.prototype.hasOwnProperty.call(e,t)){this.vars[t]=e[t];var r=[];for(var n in this.vars)Object.prototype.hasOwnProperty.call(this.vars,n)&&r.push(this.vars[n]);this.name=r.join(", ")}},f.prototype.removeVar=function(e){var t=!1;for(var r in this.vars)r===e&&(this.vars.delete(r),t=!0);if(!t){var n={};for(var o in this.vars)this.vars[o]===e?t=!0:n[o]=this.vars[o];this.vars=n}if(t){var i=[];for(var s in this.vars)Object.prototype.hasOwnProperty.call(this.vars,s)&&i.push(this.vars[s]);this.name=i.join(", ")}},c.NODE_STATUS=d,c.prototype._makeChaining=function(e){var s=this;c.expand(e).forEach(function(o){if(o.length<2)throw new Error("Bad process chain (".concat(o.length,"elt)"));s.chains.push([]);var i=s.nodes.map(function(e){return e.id});o.forEach(function(e,t){if(0!==t){var r=i.indexOf(o[t-1]);if(r<0)throw new Error("Process chain element (".concat(o[t-1],") not found"));var n=i.indexOf(o[t]);if(n<0)throw new Error("Process chain element (".concat(o[t],") not found"));r!==n&&s.chains[s.chains.length-1].push([r,n])}},s)},this)},c.prototype.idxOf=function(e){var t=this.nodes.map(function(e){return e.id}).indexOf(e);if(t<0)throw new Error("Graph.idxOf: ".concat(e," not found in ").concat(JSON.stringify(this.nodes)));return t},c.prototype.getNode=function(t){var r;return this.nodes.forEach(function(e){e.id===t&&(r=e)},this),r},c.prototype.getNodeFromIndex=function(e){if(!(0<=e&&e<this.nodes.length))throw new Error("Index out of range : ".concat(e," not in [0, ").concat(this.nodes.length-1,"]"));return this.nodes[e]},c.prototype.addNode=function(e){this.nodes.push(new l(e.id,e.name,e.kind))},c.prototype.removeNode=function(e){var r=this,t=this.findEdgesOf(e);t.toRemove.forEach(function(e){var t=r.edges.indexOf(e);-1<t&&r.edges.splice(t,1)},this),t.toShift.forEach(function(e){1<e.row&&(e.row-=1),1<e.col&&(e.col-=1)},this),this.nodes.splice(e,1)},c.prototype.moveLeft=function(e){if(1<e){var t=this.nodes[e-1];this.nodes[e-1]=this.nodes[e],this.nodes[e]=t}},c.prototype.moveRight=function(e){if(e<this.nodes.length-1){var t=this.nodes[e+1];this.nodes[e+1]=this.nodes[e],this.nodes[e]=t}},c.prototype.addEdge=function(e,t,r){var n=this.idxOf(e),o=this.idxOf(t),i=this.nodes[n].isMulti||this.nodes[o].isMulti;this.edges.push(new f(e,t,r,n,o,i))},c.prototype.removeEdge=function(e,t){var r=this.findEdge(e,t);this.edges.splice(r.index,1)},c.prototype.addEdgeVar=function(e,t,r){var n=this.findEdge(e,t).element;n?(console.log(r),n.addVar(r)):this.addEdge(e,t,r)},c.prototype.removeEdgeVar=function(e,t,r){var n=this.findEdge(e,t),o=n.element,i=n.index;o&&o.removeVar(r),""===o.name&&this.edges.splice(i,1)},c.prototype.findEdgesOf=function(t){var r=[],n=[];return this.edges.forEach(function(e){e.row===t||e.col===t?r.push(e):(e.row>t||e.col>t)&&n.push(e)},this),{toRemove:r,toShift:n}},c.prototype.findEdge=function(e,t){var r,n=-1,o=this.idxOf(e),i=this.idxOf(t);return this.edges.some(function(e,t){if(e.row!==o||e.col!==i)return!1;if(r)throw Error("edge have be uniq between two nodes, but got: ".concat(JSON.stringify(r)," and ").concat(JSON.stringify(e)));return r=e,n=t,!0},this),{element:r,index:n}},c._isPatchNeeded=function(e){for(var t=e.map(function(e){return e[e.length-1]}),r=t[0],n=0;n<t.length;n+=1)if(t[n]!==r)return!0;return!1},c._patchParallel=function(e){var r=this,n=[];e.forEach(function(t){t instanceof Array?n.push(t):c._isPatchNeeded(n)&&n.forEach(function(e){e.push(t)},r)},this)},c.expand=function(e){var t=function n(e){var o,i=[];return e.forEach(function(e){if(e instanceof Array){if(Object.prototype.hasOwnProperty.call(e[0],"parallel")){if(!o)throw new Error("Bad workflow structure : cannot parallel loop without previous starting point.");i=i.slice(0,i.length-1).concat(e[0].parallel.map(function(e){return[o].concat(n([e]),o)}))}else i=o?i.concat(n(e),o):i.concat(n(e));o=i[i.length-1]}else if(Object.prototype.hasOwnProperty.call(e,"parallel"))i=o?i.slice(0,i.length-1).concat(e.parallel.map(function(e){return[o].concat(n([e]))})):i.concat(e.parallel.map(function(e){return n([e])})),o=void 0;else{for(var t=i.length-1,r=!1;0<=t&&i[t]instanceof Array;)i[t]=i[t].concat(e),t-=1,r=!0;r||i.push(e),o=e}}),i}(e),n=[],o=[];return c._patchParallel(t),t.forEach(function(e){if(e instanceof Array)0<o.length&&(o.push(e[0]),n.push(o),o=[]),n.push(e);else{if(0<n.length&&0===o.length){var t=n[n.length-1],r=t[t.length-1];o.push(r)}o.push(e)}},this),0<o.length&&n.push(o),n},c.number=function(e,t){var n=void 0===t?0:t,o={},r=[];function i(e,t){e in r?r[e].push(t):r[e]=[t]}function d(e,t,r){void 0===r?(n=String(t),i(t,e)):(n="".concat(r,"-").concat(t),i(r,e)),e in o?o[e]+=",".concat(n):o[e]=n}return function t(e,r){var n=0;if(e instanceof Array)if(0===e.length)n=r;else if(1===e.length)n=t(e[0],r);else{var o=e[0],i=e.slice(1),s=t(o,r);if(i[0]instanceof Array){var a=t(i[0],s);d(o,s,a),s=a+1,i.shift()}n=t(i,s)}else if(e instanceof Object&&"parallel"in e){var u=e.parallel.map(function(e){return t(e,r)});n=Math.max.apply(null,u)}else d(e,r),n=r+1;return n}(e,n),{toNum:o,toNode:r}},t.default=c},"./src/labelizer.js":
/*!**************************!*\
  !*** ./src/labelizer.js ***!
  \**************************/
/*! exports provided: default */function(e,t,r){"use strict";function u(){}r.r(t),u.strParse=function(e,t){if(""===e)return[{base:"",sub:void 0,sup:void 0}];var r=e.split(",");if(!1===t)return r.map(function(e){return{base:e,sub:void 0,sup:void 0}});var s=/_/g,a=/([0-9-]+:)?([&#;A-Za-z0-9-.]+)(_[&#;A-Za-z0-9-._]+)?(\^.+)?/;return r.map(function(e){var t,r,n;if(1<(e.match(s)||[]).length){var o=e.match(/(.+)\^(.+)/);return o?{base:o[1],sub:void 0,sup:o[2]}:{base:e,sub:void 0,sup:void 0}}var i=e.match(a);if(!i)throw new Error("Labelizer.strParse: Can not parse '".concat(e,"'"));return t=(i[1]?i[1]:"")+i[2],i[3]&&(r=i[3].substring(1)),i[4]&&(n=i[4].substring(1)),{base:t,sub:r,sup:n}},this)},u._createVarListLabel=function(i,e,s,a,t){u.strParse(e,t).every(function(e,t,r){var n=0,o=0;return a<1||t<5&&s.nodes()[0].getBBox().width<100?(s.append("tspan").html(e.base),e.sub&&(n=10,s.append("tspan").attr("class","sub").attr("dy",n).html(e.sub)),e.sup&&(o=-10,s.append("tspan").attr("class","sup").attr("dx",-5).attr("dy",-n+o).html(e.sup),n=0),t<r.length-1&&s.append("tspan").attr("dy",-n-o).html(", "),!0):(s.append("tspan").attr("dy",-n-o).html("..."),i.classed("ellipsized",!0),!1)},this)},u._createLinkNbLabel=function(e,t,r){var n=t.split(","),o="".concat(n.length," var");1<n.length&&(o+="s"),r.append("tspan").html(o),e.classed("ellipsized",!0)},u.labelize=function(){var n=0,o=!0,i=!1,s="node";function t(r){r.each(function(e){var t=r.append("text");i&&"node"!==s?u._createLinkNbLabel(r,e.name,t):u._createVarListLabel(r,e.name,t,n,o)})}return t.ellipsis=function(e){return arguments.length?(n=e,t):n},t.subSupScript=function(e){return arguments.length?(o=e,t):o},t.linkNbOnly=function(e){return arguments.length?(i=e,t):i},t.labelKind=function(e){return arguments.length?(s=e,t):s},t},u.tooltipize=function(){var t="",n=!1;function r(e){var r=[];n?u.strParse(t).forEach(function(e){var t=e.base;e.sub&&(t+="<sub>".concat(e.sub,"</sub>")),e.sup&&(t+="<sup>".concat(e.sup,"</sup>")),r.push(t)}):r=t.split(",");e.html(r.join(", "))}return r.text=function(e){return arguments.length?(t=e,r):t},r.subSupScript=function(e){return arguments.length?(n=e,r):n},r},t.default=u},"./test/xdsm-test.js":
/*!***************************!*\
  !*** ./test/xdsm-test.js ***!
  \***************************/
/*! no exports provided */function(e,t,r){"use strict";r.r(t);var n=r(/*! ../src/labelizer */"./src/labelizer.js"),o=r(/*! ../src/graph */"./src/graph.js"),i=r(/*! tape */"./node_modules/tape/index.js");function s(){return new o.default({nodes:[{id:"A"},{id:"B"},{id:"C"},{id:"D"},{id:"E"}],edges:[{from:"A",to:"B",name:"a, b"},{from:"C",to:"A",name:"CA"},{from:"C",to:"B",name:"CB"},{from:"C",to:"D",name:"CD"},{from:"E",to:"A",name:"EA"}],workflow:[]})}function a(){return new o.default({nodes:[{id:"A"},{id:"B"},{id:"C"},{id:"D"},{id:"E"}],edges:[{from:"A",to:"B",vars:{1:"a",2:"b"}},{from:"C",to:"A",vars:{1:"a",3:"c"}},{from:"C",to:"B",vars:{3:"c",2:"b"}},{from:"C",to:"D",vars:{3:"c",4:"d"}},{from:"E",to:"A",vars:{5:"e",1:"a"}}],workflow:[]})}i("Labelizer.strParse('') returns [{'base':'', 'sub':undefined, 'sup':undefined}]",function(e){e.deepEqual(n.default.strParse(""),[{base:"",sub:void 0,sup:void 0}]),e.end()}),i("Labelizer.strParse('+A') throws an error",function(e){e.throws(function(){n.default.strParse("+")},"should throw an error"),e.end()}),i("Labelizer.strParse('ConvCheck') returns [{'base':'ConvCheck', 'sub':undefined, 'sup':undefined}]",function(e){e.deepEqual(n.default.strParse("ConvCheck"),[{base:"ConvCheck",sub:void 0,sup:void 0}]),e.end()}),i("Labelizer.strParse('x') returns [{'base':'x', 'sub':undefined, 'sup':undefined}]",function(e){e.deepEqual(n.default.strParse("x"),[{base:"x",sub:void 0,sup:void 0}]),e.end()}),i("Labelizer.strParse('&#x03BB') returns [{'base':'&#x03BB', 'sub':undefined, 'sup':undefined}]",function(e){e.deepEqual(n.default.strParse("&#x03BB"),[{base:"&#x03BB",sub:void 0,sup:void 0}]),e.end()}),i("Labelizer.strParse('&#x03BB_&#x03BB^&#x03BB') returns [{'base':'&#x03BB', 'sub':'&#x03BB', 'sup':'&#x03BB'}]",function(e){e.deepEqual(n.default.strParse("&#x03BB_&#x03BB^&#x03BB"),[{base:"&#x03BB",sub:"&#x03BB",sup:"&#x03BB"}]),e.end()}),i("Labelizer.strParse('Optimization') returns [{'base':'Optimization', 'sub':undefined, 'sup':undefined}]",function(e){e.deepEqual(n.default.strParse("Optimization"),[{base:"Optimization",sub:void 0,sup:void 0}]),e.end()}),i("Labelizer.strParse('x_12') returns [{'base':'x', 'sub': '12', 'sup':undefined}]",function(e){e.deepEqual(n.default.strParse("x_12"),[{base:"x",sub:"12",sup:void 0}]),e.end()}),i("Labelizer.strParse('x_13^{(0)}') returns [{'base':'x', 'sub': '13', 'sup': '{(0)}'}]",function(e){e.deepEqual(n.default.strParse("x_13^{(0)}"),[{base:"x",sub:"13",sup:"{(0)}"}]),e.end()}),i("Labelizer.strParse('x_13^0, y_1^{*}') returns [{'base': 'x', 'sub': '13', 'sup': '{*}'}, {'base':'y', 'sub': '1', 'sup': '*'}]",function(e){e.deepEqual(n.default.strParse("x_13^{(0)}, y_1^{*}"),[{base:"x",sub:"13",sup:"{(0)}"},{base:"y",sub:"1",sup:"{*}"}]),e.end()}),i("Labelizer.strParse('1:Opt') returns [{'base':'1:Opt', 'sub':undefined, 'sup':undefined}]",function(e){e.deepEqual(n.default.strParse("1:Opt"),[{base:"1:Opt",sub:void 0,sup:void 0}]),e.end()}),i("Labelizer.strParse('1:L-BFGS-B') returns [{'base':'1:L-BFGS-B', 'sub':undefined, 'sup':undefined}]",function(e){e.deepEqual(n.default.strParse("1:L-BFGS-B"),[{base:"1:L-BFGS-B",sub:void 0,sup:void 0}]),e.end()}),i("Labelizer.strParse('y_12_y_34') returns [{'base':'y_12_y_34', 'sub':undefined, 'sup':undefined}]",function(e){e.deepEqual(n.default.strParse("y_12_y_34"),[{base:"y_12_y_34",sub:void 0,sup:void 0}]),e.end()}),i("Labelizer.strParse('y_12_y_34^*') returns [{'base':'y_12_y_34', 'sub':undefined, 'sup':'*'}]",function(e){e.deepEqual(n.default.strParse("y_12_y_34^*"),[{base:"y_12_y_34",sub:void 0,sup:"*"}]),e.end()}),i("Graph.expand(['a']) returns [['a']]",function(e){e.deepEqual(o.default.expand(["a"]),[["a"]]),e.end()}),i("Graph.expand([['a']]) returns [['a']]",function(e){e.deepEqual(o.default.expand([["a"]]),[["a"]]),e.end()}),i("Graph.expand(['a', 'b']) returns [['a', 'b']]",function(e){e.deepEqual(o.default.expand(["a","b"]),[["a","b"]]),e.end()}),i("Graph.expand([['a', 'b']]) returns [['a', 'b']]",function(e){e.deepEqual(o.default.expand([["a","b"]]),[["a","b"]]),e.end()}),i("Graph.expand(['a', ['b']]) returns [['a', 'b', 'a']]",function(e){e.deepEqual(o.default.expand(["a",["b"]]),[["a","b","a"]]),e.end()}),i("Graph.expand([['a'], 'b']) returns ['a', 'b']",function(e){e.deepEqual(o.default.expand([["a"],"b"]),[["a","b"]]),e.end()}),i("Graph.expand([['a'], 'b', 'c']) returns ['a', 'b', 'c']",function(e){e.deepEqual(o.default.expand([["a"],"b","c"]),[["a","b","c"]]),e.end()}),i("Graph.expand(['a', ['b'], 'c']) returns [['a', 'b', 'a', 'c']]",function(e){e.deepEqual(o.default.expand(["a",["b"],"c"]),[["a","b","a","c"]]),e.end()}),i("Graph.expand(['a', [['b']], 'c']) returns [['a', 'b', 'a', 'c']]",function(e){e.deepEqual(o.default.expand(["a",[["b"]],"c"]),[["a","b","a","c"]]),e.end()}),i("Graph.expand(['a', [['b', [d]]], 'c']) returns [['a', 'b', 'd', 'b', 'a', 'c']]",function(e){e.deepEqual(o.default.expand(["a",[["b",["d"]]],"c"]),[["a","b","d","b","a","c"]]),e.end()}),i("Graph.expand(['a', ['b1', 'b2'], 'c']) returns [['a', 'b1', 'b2', 'a', 'c']]",function(e){e.deepEqual(o.default.expand(["a",["b1","b2"],"c"]),[["a","b1","b2","a","c"]]),e.end()}),i("Graph.expand(['a0', ['b1', 'b2', 'b3'], 'c3']) returns [['a0', 'b1', 'b2', 'b3', 'a0', 'c3']]",function(e){e.deepEqual(o.default.expand(["a0",["b1","b2","b3"],"c3"]),[["a0","b1","b2","b3","a0","c3"]]),e.end()}),i("Graph.expand(['opt', ['mda', ['d1', 'd2', 'd3'],'func']]) returns [['opt', 'mda', 'd1', 'd2', 'd3', 'mda','func', 'opt']]",function(e){e.deepEqual(o.default.expand(["opt",["mda",["d1","d2","d3"],"func"]]),[["opt","mda","d1","d2","d3","mda","func","opt"]]),e.end()}),i("Graph.expand([{parallel: ['d1', 'd2']}]) returns [[d1], [d2]]",function(e){e.deepEqual(o.default.expand([{parallel:["d1","d2"]}]),[["d1"],["d2"]]),e.end()}),i("Graph.expand([{parallel: ['d1', 'd2']}]) returns [[d1], [d2]]",function(e){e.deepEqual(o.default.expand([{parallel:["d1","d2"]}]),[["d1"],["d2"]]),e.end()}),i("Graph.expand(['opt', {parallel: ['d1', 'd2', 'd3']}]) returns [['opt', 'd1'], ['opt', 'd2'], ['opt', 'd3']]",function(e){e.deepEqual(o.default.expand(["opt",{parallel:["d1","d2","d3"]}]),[["opt","d1"],["opt","d2"],["opt","d3"]]),e.end()}),i("Graph.expand(['opt', [{parallel: ['d1', 'd2', 'd3']}]]) returns [['opt', 'd1', 'opt'], ['opt', 'd2', 'opt'], ['opt', 'd3', 'opt']]",function(e){e.deepEqual(o.default.expand(["opt",[{parallel:["d1","d2","d3"]}]]),[["opt","d1","opt"],["opt","d2","opt"],["opt","d3","opt"]]),e.end()}),i("Graph.expand(['mda', {parallel: ['d1', 'd2', 'd3']}, 'd4']) returns [['mda', 'd1', 'd4'], ['mda', 'd2', 'd4'], ['mda', 'd3', 'd4']]",function(e){e.deepEqual(o.default.expand(["mda",{parallel:["d1","d2","d3"]},"d4"]),[["mda","d1","d4"],["mda","d2","d4"],["mda","d3","d4"]]),e.end()}),i("Graph.expand(['opt', 'mda', {parallel: ['d1', 'd2', 'd3']}, 'd4']]) returns [['opt', 'mda'], ['mda', 'd1', 'd4'], ['mda', 'd2', 'd4'], ['mda', 'd3', 'd4']]",function(e){e.deepEqual(o.default.expand(["opt","mda",{parallel:["d1","d2","d3"]},"d4"]),[["opt","mda"],["mda","d1","d4"],["mda","d2","d4"],["mda","d3","d4"]]),e.end()}),i("Graph.expand(['opt', ['mda', {parallel: ['d1', 'd2', 'd3']}, 'd4']]) returns [['opt', 'mda'], ['mda', 'd1', 'd4'], ['mda', 'd2', 'd4'], ['mda', 'd3', 'd4'], ['d4', 'opt']]",function(e){e.deepEqual(o.default.expand(["opt",["mda",{parallel:["d1","d2","d3"]},"d4"]]),[["opt","mda"],["mda","d1","d4"],["mda","d2","d4"],["mda","d3","d4"],["d4","opt"]]),e.end()}),i("Graph.expand((['_U_', ['opt', ['mda', {parallel: ['d1', 'd2', 'd3']}, 'd4']]]) returns [['_U_', 'opt', 'mda'], ['mda', 'd1', 'd4'], ['mda', 'd2', 'd4'], ['mda', 'd3', 'd4'], ['d4', 'opt', '_U_']]",function(e){e.deepEqual(o.default.expand(["_U_",["opt",["mda",{parallel:["d1","d2","d3"]},"d4"]]]),[["_U_","opt","mda"],["mda","d1","d4"],["mda","d2","d4"],["mda","d3","d4"],["d4","opt","_U_"]]),e.end()}),i("Graph.expand((['_U_', ['opt', ['mda', ['d1', 'd2']]]]) returns [['_U_', 'opt', 'mda', 'd1', 'd2', 'mda', 'opt', '_U_']]",function(e){e.deepEqual(o.default.expand(["_U_",["opt",["mda",["d1","d2"]]]]),[["_U_","opt","mda","d1","d2","mda","opt","_U_"]]),e.end()}),i("Graph.expand((['_U_', ['opt', ['mda', ['d1', 'd2'], 'mda', ['d1', 'd2']]]]) returns [['_U_', 'opt', 'mda', 'd1', 'd2', 'mda', 'mda', 'd1', 'd2', 'mda', 'opt', '_U_']]",function(e){e.deepEqual(o.default.expand(["_U_",["opt",["mda",["d1","d2"],"mda",["d1","d2"]]]]),[["_U_","opt","mda","d1","d2","mda","mda","d1","d2","mda","opt","_U_"]]),e.end()}),i("Graph.expand((['_U_', ['opt', ['mda', ['d1', 'd2'], {parallel: ['sc1', 'sc2']},'mda', ['d1', 'd2']]]]) returns [['_U_', 'opt', 'mda', 'd1', 'd2', 'mda'], ['mda', 'sc1', 'mda'], ['mda', 'sc2', 'mda'], ['mda', 'd1', 'd2', 'mda', 'opt', '_U_']]",function(e){e.deepEqual(o.default.expand(["_U_",["opt",["mda",["d1","d2"],{parallel:["sc1","sc2"]},"mda",["d1","d2"]]]]),[["_U_","opt","mda","d1","d2","mda"],["mda","sc1","mda"],["mda","sc2","mda"],["mda","d1","d2","mda","opt","_U_"]]),e.end()}),i("Graph.expand((['d1', {parallel: ['sc1', 'sc2']}, 'd2']) returns [['d1', 'sc1', 'd2'], ['d1', 'sc2', 'd2']]",function(e){e.deepEqual(o.default.expand(["d1",{parallel:["sc1","sc2"]},"d2"]),[["d1","sc1","d2"],["d1","sc2","d2"]]),e.end()}),i("Graph.expand((['opt', ['d1', {parallel: ['sc1', 'sc2']}]]) returns [['opt', 'd1'] ['d1', 'sc1', 'opt'], ['d1', 'sc2', 'opt']]",function(e){e.deepEqual(o.default.expand(["opt",["d1",{parallel:["sc1","sc2"]}]]),[["opt","d1"],["d1","sc1","opt"],["d1","sc2","opt"],["opt","opt"]]),e.end()}),i("Graph.chains should expand as list of index couples",function(e){var t=new o.default({nodes:[{id:"Opt",name:"Opt"},{id:"MDA",name:"MDA"},{id:"DA1",name:"DA1"},{id:"DA2",name:"DA2"},{id:"DA3",name:"DA3"},{id:"Func",name:"Func"}],edges:[],workflow:["Opt",["MDA",["DA1","DA2","DA3"],"Func"]]});e.deepEqual(t.chains,[[[1,2],[2,3],[3,4],[4,5],[5,2],[2,6],[6,1]]]),e.end()}),i("Graph.chains should expand as list of index couples",function(e){var t=new o.default({nodes:[{id:"Opt",name:"Opt"},{id:"DA1",name:"DA1"},{id:"DA2",name:"DA2"},{id:"DA3",name:"DA3"},{id:"Func",name:"Func"}],edges:[],workflow:[["Opt",["DA1"],"Opt",["DA2"],"Opt",["DA3"],"Func"]]});e.deepEqual(t.chains,[[[1,2],[2,1],[1,3],[3,1],[1,4],[4,1],[1,5]]]),e.end()}),i("Graph.number(['d1']) returns {'toNum':{d1: '0'}, 'toNodes':[['d1']])",function(e){e.deepEqual(o.default.number(["d1"]),{toNum:{d1:"0"},toNode:[["d1"]]}),e.equal(o.default.number(["d1"]).toNode.length,1),e.end()}),i("Graph.number(['d1', 'd1']) returns {'toNum':{d1: '0,1'}, 'toNodes':[['d1'],['d1']]})",function(e){e.deepEqual(o.default.number(["d1","d1"]),{toNum:{d1:"0,1"},toNode:[["d1"],["d1"]]}),e.end()}),i("Graph.number(['mda', 'd1']) returns {'toNum':{mda:'0', d1: '1'}, 'toNode':[['mda'], ['d1']]})",function(e){e.deepEqual(o.default.number(["mda","d1"]),{toNum:{mda:"0",d1:"1"},toNode:[["mda"],["d1"]]}),e.end()}),i("Graph.number(['mda', 'd1', 'd2', 'd3']) returns {mda: '0', d1: '1', d2: '2', d3: '3'})",function(e){e.deepEqual(o.default.number(["mda","d1","d2","d3"]).toNum,{mda:"0",d1:"1",d2:"2",d3:"3"}),e.end()}),i("Graph.number(['mda', ['d1', 'd2', 'd3']]) returns {mda: '0,4-1', d1: '1', d2: '2', d3: '3'} )",function(e){e.deepEqual(o.default.number(["mda",["d1","d2","d3"]]).toNum,{mda:"0,4-1",d1:"1",d2:"2",d3:"3"}),e.end()}),i("Graph.number(['mda', {parallel:['d1', 'd2', 'd3']}]) returns {'mda': '0', 'd1': '1', 'd2': '1', 'd3': '1'})",function(e){e.deepEqual(o.default.number(["mda",{parallel:["d1","d2","d3"]}]).toNum,{mda:"0",d1:"1",d2:"1",d3:"1"}),e.end()}),i("Graph.number(['mda', [{parallel:['d1', 'd2', 'd3']}]]) returns {'toNum':{'mda': '0,2-1', 'd1': '1', 'd2': '1', 'd3': '1'}, 'toNode':[['mda'], ['d1','d2','d3']]})",function(e){e.deepEqual(o.default.number(["mda",[{parallel:["d1","d2","d3"]}]]).toNum,{mda:"0,2-1",d1:"1",d2:"1",d3:"1"}),e.deepEqual(o.default.number(["mda",[{parallel:["d1","d2","d3"]}]]).toNode,[["mda"],["d1","d2","d3"],["mda"]]),e.end()}),i("Graph.number(['opt', 'mda', ['d1', 'd2', 'd3']]) returns {'opt': '0', 'mda': '1,5-2', 'd1': '2', 'd2': '3', 'd3': '4'})",function(e){e.deepEqual(o.default.number(["opt","mda",["d1","d2","d3"]]).toNum,{opt:"0",mda:"1,5-2",d1:"2",d2:"3",d3:"4"}),e.end()}),i("Graph.number([['opt', ['mda', ['d1', 'd2', 'd3']]], 'd4']) returns {'opt': '0,6-1', 'mda': '1,5-2', 'd1': '2', 'd2': '3', 'd3': '4', 'd4': '7'})",function(e){e.deepEqual(o.default.number([["opt",["mda",["d1","d2","d3"]]],"d4"]).toNum,{opt:"0,6-1",mda:"1,5-2",d1:"2",d2:"3",d3:"4",d4:"7"}),e.end()}),i("Graph.number([['Opt', ['mda', ['d1'], 's1']]]) returns {'Opt': '0,5-1', 'mda': '1,3-2', 'd1': '2', 's1': '4'})",function(e){e.deepEqual(o.default.number([["Opt",["mda",["d1"],"s1"]]]).toNum,{Opt:"0,5-1",mda:"1,3-2",d1:"2",s1:"4"}),e.end()}),i("Graph.findEdgesOf(nodeIdx) returns edges to remove and edges to delete in case of node removal",function(e){var t=s();e.deepEqual(t.findEdgesOf(1),{toRemove:[t.edges[0],t.edges[1],t.edges[4]],toShift:[t.edges[2],t.edges[3]]}),e.deepEqual(t.findEdgesOf(3),{toRemove:[t.edges[1],t.edges[2],t.edges[3]],toShift:[t.edges[4]]}),e.deepEqual(t.findEdgesOf(4),{toRemove:[t.edges[3]],toShift:[t.edges[4]]}),e.end()}),i("Graph.addNode()",function(e){var t=s();e.equal(t.nodes.length,6),t.addNode({id:"F",name:"F",kind:"analysis"}),e.equal(t.nodes.length,7),e.end()}),i("Graph.removeNode()",function(e){var t=s();e.equal(t.nodes.length,6),t.removeNode(4),e.equal(t.nodes.length,5),e.end()}),i("Graph.getNode()",function(e){var t=s();e.equal(t.getNode("A"),t.nodes[1]),e.equal(t.getNode("E"),t.nodes[5]),e.end()}),i("Graph.idxOf()",function(e){var t=s();e.equal(t.idxOf("B"),2),e.equal(t.idxOf("E"),5),e.end()}),i("Graph constructor should create a graph without edges or workflow input data)",function(e){var t=new o.default({nodes:[{id:"A"},{id:"B"}]});e.deepEqual(t.edges,[]),e.deepEqual(t.chains,[]),e.end()}),i("Graph nodes have a status UNKNOWN by default",function(e){var t=new o.default({nodes:[{id:"A"},{id:"B"}]});e.deepEqual(t.getNode("A").status,o.default.NODE_STATUS.UNKNOWN),e.end()}),i("Graph nodes can be to a given status PENDING, RUNNING, DONE or FAILED",function(e){var t=new o.default({nodes:[{id:"A",status:"PENDING"},{id:"B",status:"RUNNING"},{id:"C",status:"DONE"},{id:"D",status:"FAILED"}]});e.deepEqual(t.getNode("A").status,o.default.NODE_STATUS.PENDING),e.deepEqual(t.getNode("B").status,o.default.NODE_STATUS.RUNNING),e.deepEqual(t.getNode("C").status,o.default.NODE_STATUS.DONE),e.deepEqual(t.getNode("D").status,o.default.NODE_STATUS.FAILED),e.end()}),i("Graph throws an error if a node status string not known",function(e){e.throws(function(){new o.default({nodes:[{id:"A",status:"BADSTATUS"}]})},"should throw an error"),e.end()}),i("Graph edge can have vars infos id/names from name",function(e){var t=s().findEdge("A","B");e.deepEqual(t.element.vars,{0:"a",1:"b"}),e.end()}),i("Graph edge can have vars infos id/names",function(e){var t=a();e.equal(t.getNode("E"),t.nodes[5]);var r=t.findEdge("C","D").element;e.equal(r.vars[3],"c"),e.equal(r.vars[4],"d"),e.deepEqual(r.vars,{3:"c",4:"d"}),e.equal(r.name,"c, d"),e.end()}),i("Graph add new var between two given nodes not linked",function(e){var t=a();t.addEdgeVar("A","D",{4:"d"});var r=t.findEdge("A","D").element;e.equal(r.vars[4],"d"),e.deepEqual(r.vars,{4:"d"}),e.equal(r.name,"d"),e.end()}),i("Graph a var should appear once even if added twice",function(e){var t=a();t.addEdgeVar("A","D",{4:"d"}),t.addEdgeVar("A","D",{4:"d"});var r=t.findEdge("A","D").element;e.equal(r.name,"d"),t.removeEdge("A","D");t.findEdge("A","D").index;e.equal(r.index,void 0),e.end()}),i("Graph add new var between two given nodes already linked",function(e){var t=a();t.addEdgeVar("A","B",{4:"d"});var r=t.findEdge("A","B").element;e.deepEqual(r.vars,{1:"a",2:"b",4:"d"}),e.equal(r.name,"a, b, d"),e.end()}),i("Remove var of an edge",function(e){var t=a().findEdge("A","B").element;t.removeVar("b"),e.equal(t.name,"a"),e.end()}),i("Remove edge between two given nodes",function(e){var t=a(),r=t.findEdge("E","A").element;e.notEqual(r,void 0),t.removeEdge("E","A"),r=t.findEdge("E","A").element,e.equal(r,void 0),e.end()}),i("Remove edge one var between two given nodes",function(e){var t=a(),r=t.findEdge("E","A").element;e.notEqual(r,void 0),t.removeEdgeVar("E","A","e"),r=t.findEdge("E","A").element,e.deepEqual(r.vars,{1:"a"}),e.end()}),i("Remove edge all vars between two given nodes",function(e){var t=a(),r=t.findEdge("E","A").element;e.notEqual(r,void 0),t.removeEdgeVar("E","A","e"),t.removeEdgeVar("E","A","a"),r=t.findEdge("E","A").element,e.equal(r,void 0),e.end()})},0:
/*!**********************!*\
  !*** util (ignored) ***!
  \**********************/
/*! no static exports found */function(e,t){},1:
/*!**********************!*\
  !*** util (ignored) ***!
  \**********************/
/*! no static exports found */function(e,t){},2:
/*!********************************!*\
  !*** ./util.inspect (ignored) ***!
  \********************************/
/*! no static exports found */function(e,t){}});
//# sourceMappingURL=xdsm-test.bundle.js.map